OC.L10N.register(
    "notes",
    {
    "Notes" : "Notater",
    "Error" : "Feil",
    "New note" : "Nytt notat",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finnes ulagrede notater. Å forlate siden vil forkaste alle endringer!",
    "Display mode for notes" : "Visningsmodus for notater",
    "Open in edit mode" : "Åpne i redigeringsmodus",
    "Open in preview mode" : "Åpne i forhåndsvisningsmodus",
    "No notes yet" : "Ingen notater enda",
    "Insert image" : "Sett inn bilde",
    "All notes" : "Alle notater",
    "Categories" : "Kategorier",
    "Loading …" : "Laster...",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "This week" : "Denne uken",
    "Last week" : "Forrige uke",
    "This month" : "Denne måneden",
    "Last month" : "Forrige måned",
    "Rename" : "Endre navn",
    "Delete note" : "Slett notat",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "Use current version" : "Bruk siste versjon",
    "Details" : "Detaljer",
    "Edit" : "Rediger",
    "Preview" : "Forhåndsvis",
    "Category" : "Kategori",
    "Uncategorized" : "Ukategorisert",
    "Saving failed!" : "Lagring mislyktes!",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "Android app" : "Android-app",
    "iOS app" : "iOS-app"
},
"nplurals=2; plural=(n != 1);");
