OC.L10N.register(
    "notes",
    {
    "Notes" : "Noter",
    "Error" : "Fejl",
    "New note" : "Ny note",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
    "Display mode for notes" : "Visningstilstand for noter",
    "Open in edit mode" : "Åbn i redigeringstilstand",
    "Open in preview mode" : "Åbn forhåndsvisning",
    "No notes yet" : "Ingen noter endnu",
    "Insert image" : "Indsæt billede",
    "All notes" : "Alle noter",
    "Categories" : "Kategorier",
    "Loading …" : "Indlæser…",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "This week" : "Denne uge",
    "Last week" : "Sidste uge",
    "This month" : "Denne måned",
    "Last month" : "Seneste måned",
    "Rename" : "Omdøb",
    "Delete note" : "Slet note",
    "Remove from favorites" : "Fjernet fra favoritter",
    "Add to favorites" : "Føj til favoritter",
    "Use current version" : "Brug aktuelle version",
    "Details" : "Detaljer",
    "Edit" : "Redigér",
    "Preview" : "Vis eksempel",
    "Category" : "Katergori",
    "Uncategorized" : "Udenfor kategori",
    "Saving failed!" : "Kunne ikke gemme!",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "Android app" : "Android app",
    "iOS app" : "iOS app"
},
"nplurals=2; plural=(n != 1);");
