OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Reading notes from filesystem has failed." : "La lecture des notes du système de fichiers a échoué.",
    "Error" : "Erreur",
    "New note" : "Nouvelle note",
    "Distraction-free notes and writing" : "Notes et écriture sans distraction",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notes est une application de prise de notes sans distraction pour [Nextcloud](https://www.nextcloud.com/). Elle offre des catégories pour une meilleure organisation et supporte la syntaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). Les notes sont sauvegardées en tant que fichiers sur votre Nextcloud, vous pouvez ainsi les consulter et les éditer avec n'importe quel client Nextcloud. De plus, une [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) permet une intégration facile dans des applications de notes de tierce partie (actuellement, les notes [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) et la [console](https://git.danielmoch.com/nncli/about) sont supportées, offrant un accès pratique à vos notes Nextcloud). D'autres fonctionnalités incluent la possibilité d'ajouter des notes en favori.",
    "Please see Nextcloud server log for details." : "Veuillez consulter le journal du serveur Nextcloud pour plus de détails.",
    "Deleted {title}" : "La note {title} a été supprimée",
    "Undo Delete" : "Annuler la suppression",
    "Note recovered" : "Note restaurée",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Il y a des notes non sauvegardées. Quitter la page perdra toutes les modifications !",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} note supprimée","{number} notes supprimées","{number} notes supprimées"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} note restaurée","{number} notes restaurées","{number} notes restaurées"],
    "Notes settings" : "Paramètres des notes",
    "Folder to store your notes" : "Dossier pour stocker vos notes",
    "Root directory" : "Dossier racine",
    "File extension for new notes" : "Type de fichier des nouvelles notes",
    "Display mode for notes" : "Mode d'affichage des notes",
    "User defined" : "Défini par l'utilisateur",
    "Open in edit mode" : "Ouvrir en mode édition",
    "Open in preview mode" : "Ouvrir en mode aperçu",
    "No notes yet" : "Aucune note pour l'instant",
    "Upload image" : "Téléverser une image",
    "Insert image" : "Insérer une image",
    "Select an image" : "Sélectionner une image",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Vous ne pouvez pas sélectionner des images en dehors du dossier de vos notes. Le dossier de vos notes est : {folder}",
    "Wrong image" : "Image erronée",
    "The file was not uploaded. Check your server logs." : "Le fichier n'a pas été envoyé. Consulter les journaux du serveur.",
    "All notes" : "Toutes les notes",
    "Categories" : "Catégories",
    "Loading …" : "Chargement …",
    "Today" : "Aujourd'hui",
    "Yesterday" : "Hier",
    "This week" : "Cette semaine",
    "Last week" : "Semaine dernière",
    "This month" : "Ce mois-ci",
    "Last month" : "Le mois dernier",
    "Rename" : "Renommer",
    "Note's title" : "Titre de la note",
    "Delete note" : "Supprimer la note",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "Error during preparing note for deletion." : "Erreur lors de la préparation de la suppression de la note.",
    "The note has been changed in another session. Please choose which version should be saved." : "La note a été modifiée dans une autre session. Veuillez choisir la version à enregistrer.",
    "Use version from server" : "Utiliser la version provenant du serveur",
    "Use current version" : "Utiliser la version actuelle",
    "Empty note" : "Note vide",
    "Write …" : "écrit ...",
    "Details" : "Détails",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modifier",
    "Preview" : "Prévisualiser",
    "Exit full screen" : "Quitter le plein écran",
    "Full screen" : "Plein écran",
    "Note is read-only. You cannot change it." : "La note est en lecture seule. Vous ne pouvez pas la modifier.",
    "Save failed. Click to retry." : "L’enregistrement a échoué. Cliquez pour réessayer.",
    "Update conflict. Click for resolving manually." : "Conflit de mise à jour. Cliquez pour le résoudre manuellement.",
    "Error from Nextcloud server: {msg}" : "Erreur du serveur Nextcloud : {msg}",
    "Category" : "Catégorie",
    "Uncategorized" : "Non catégorisé",
    "Set category" : "Définir une catégorie",
    "Click here to save manually" : "Cliquez ici pour enregistrer manuellement",
    "Saving failed!" : "L'enregistrement a échoué !",
    "Last modified: {date}" : "Dernière modification : {date}",
    "Note has unsaved changes" : "Note a des changements non sauvegardés",
    "Subcategory" : "Sous-catégorie",
    "_%n word_::_%n words_" : ["%n mot","%n mots","%n mots"],
    "_%n character_::_%n characters_" : ["%n caractère","%n caractères","%n caractères"],
    "Write down your thoughts without any distractions." : "Écrivez vos idées facilement.",
    "Use Markdown markups to style your text." : "Utilisez la syntaxe Markdown pour mettre en forme votre texte.",
    "Organize your notes in categories." : "Organisez vos notes en catégories.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installez l'application pour votre téléphone portable afin d'accéder à vos notes de partout.",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Commencez à écrire une note en cliquant sur “{newnote}” dans la navigation de l'application.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Vous pouvez créer des sous-catégories en utilisant le séparateur “/” entre le parent et la sous-catégorie, par exemple “{père}/{fils}”.",
    "Note not found." : "Note non trouvée.",
    "Note is locked." : "La note est verrouillée.",
    "Insufficient storage." : "Espace libre insuffisant.",
    "See JavaScript console and server log for details." : "Voir la console Javascript et le journal du serveur pour plus de détails.",
    "Updating settings has failed." : "La mise à jour des paramètres a échoué.",
    "Fetching notes for dashboard has failed." : "La récupération des notes pour le tableau de bord a échoué.",
    "Fetching notes has failed." : "La recherche de notes a échoué.",
    "Fetching note {id} has failed." : "La recherche de la note {id} a échoué.",
    "Refreshing note {id} has failed." : "L'actualisation de la note {id} a échoué.",
    "Renaming note {id} has failed." : "Impossible de renommer la note {id}.",
    "Creating new note has failed." : "La création d'une nouvelle note a échoué.",
    "Saving note {id} has failed." : "L'enregistrement de la note {id} a échoué.",
    "Updating title for note {id} has failed." : "La mise à jour du titre de la note {id} a échoué.",
    "Undo delete has failed for note {title}." : "Impossible d'annuler la suppression de la note {title}.",
    "Deleting note {id} has failed." : "La suppression de la note {id} a échoué.",
    "Toggling favorite for note {id} has failed." : "Le changement de favori pour la note {id} a échoué.",
    "Updating the note's category has failed. Is the target directory writable?" : "Impossible de mettre à jour la catégorie de la note. Vérifiez que vous avez le droit d'écriture dans ce dossier.",
    "Updating the category for note {id} has failed." : "La mise à jour de la catégorie pour la note {id} a échoué.",
    "Development Mode" : "Mode développeur",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Il semble que l'application Notes a été installée depuis une source de développement. Veuillez plutôt l'installer depuis le <a href=\"%1$s\">magasin d'applications Nextcloud App</a> officiel. Si vous voulez construire l'application Notes par vous-même, veuillez suivre les <a href=\"%2$s\">instructions pour le développeur</a>."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
