OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "Reading notes from filesystem has failed." : "La lettura delle note dal filesystem non è riuscita.",
    "Error" : "Errore",
    "New note" : "Nuova nota",
    "Distraction-free notes and writing" : "Note senza distrazioni e scrittura",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Note è un'applicazione per prendere note senza distrazioni per [Nextcloud](https://www.nextcloud.com/). Fornisce categorie per un'organizzazione migliore e supporta la formattazione utilizzando la sintassi [Markdown](https://it.wikipedia.org/wiki/Markdown). Le note sono salvate come file nel tuo Nextcloud, in modo che tu possa visualizzarle e modificarle con ogni client Nextcloud. Inoltre, un'[API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) separata consente un'integrazione semplice in applicazioni di terze parti (attualmente ci sono applicazioni di note per [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) e la [console](https://git.danielmoch.com/nncli/about) che consentono un comodo accesso alle note di Nextcloud). Ulteriori funzionalità includono la marcatura delle note come preferite.",
    "Please see Nextcloud server log for details." : "Vedi i log del server Nextcloud per i dettagli.",
    "Deleted {title}" : "Eliminato {title}",
    "Undo Delete" : "Annulla eliminazione",
    "Note recovered" : "Nota ripristinata",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ci sono note non salvate. Uscita. Se lasci la pagina perderai tutte le modifiche!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Eliminata {number} nota","Eliminate {number} note","Eliminate {number} note"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Ripristinata {number} nota","Ripristinate {number} note","Ripristinate {number} note"],
    "Folder to store your notes" : "Cartella in cui memorizzare le tue note",
    "Root directory" : "Cartella principale",
    "File extension for new notes" : "Estensione dei file per le nuove note",
    "Display mode for notes" : "Modalità di visualizzazione delle note",
    "User defined" : "Utente definito",
    "Open in edit mode" : "Apri in modalità modifica",
    "Open in preview mode" : "Apri in modalità anteprima",
    "No notes yet" : "Ancora nessuna nota",
    "Upload image" : "Carica immagine",
    "Insert image" : "Inserisci immagine",
    "Select an image" : "Seleziona un'immagine",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Non è possibile selezionare immagini al di fuori della cartella delle note. La tua cartella delle note è: {folder}",
    "Wrong image" : "Immagine errata",
    "The file was not uploaded. Check your server logs." : "Il file non è stato caricato. Controlla i log del tuo server.",
    "All notes" : "Tutte le note",
    "Categories" : "Categorie",
    "Loading …" : "Caricamento...",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "This week" : "Questa settimana",
    "Last week" : "Settimana scorsa",
    "This month" : "Questo mese",
    "Last month" : "Mese scorso",
    "Rename" : "Rinomina",
    "Note's title" : "Titolo della nota",
    "Delete note" : "Elimina nota",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Error during preparing note for deletion." : "Errore durante l'eliminazione della nota.",
    "The note has been changed in another session. Please choose which version should be saved." : "La nota è stata modificata in un'altra sessione. Scegli quale versione debba essere salvata.",
    "Use version from server" : "Usa versione del server",
    "Use current version" : "Usa versione attuale",
    "Empty note" : "Nota vuota",
    "Write …" : "Scrivi...",
    "Details" : "Dettagli",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modifica",
    "Preview" : "Anteprima",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Note is read-only. You cannot change it." : "La nota è in sola lettura. Non puoi cambiarla.",
    "Save failed. Click to retry." : "Salvataggio non riuscito. Fai clic per riprovare.",
    "Update conflict. Click for resolving manually." : "Conflitto di aggiornamento. Fai clic per risolvere manualmente.",
    "Error from Nextcloud server: {msg}" : "Errore dal server di Nextcloud: {msg}",
    "Set category" : "Imposta categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Senza categoria",
    "Click here to save manually" : "Fai clic qui per salvare manualmente",
    "Saving failed!" : "Salvataggio non riuscito!",
    "Last modified: {date}" : "Ultima modifica: {date}",
    "Note has unsaved changes" : "La nota ha modifiche non salvate",
    "Subcategory" : "Sottocategoria",
    "_%n word_::_%n words_" : ["%n parola","%n parole","%n parole"],
    "_%n character_::_%n characters_" : ["%n carattere","%n caratteri","%n caratteri"],
    "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
    "Organize your notes in categories." : "Organizza le tue note in categorie.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa l'applicazione per il tuo cellulare per accedere alle tue note da ovunque.",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Puoi creare sottocategorie utilizzando \"/\" come delimitatore tra la categoria superiore e la sottocategoria, ad. es \"{parent}/{sub}\".",
    "Note not found." : "Nota non trovata.",
    "Note is locked." : "La nota è bloccata.",
    "Insufficient storage." : "Spazio di archiviazione insufficiente.",
    "See JavaScript console and server log for details." : "Vedi la console JavaScript e i log del server per i dettagli.",
    "Updating settings has failed." : "Aggiornamento delle impostazioni non riuscito.",
    "Fetching notes for dashboard has failed." : "Recupero delle note per il cruscotto non riuscito.",
    "Fetching notes has failed." : "Recupero delle note non riuscito.",
    "Fetching note {id} has failed." : "Recupero della nota {id} non riuscito.",
    "Refreshing note {id} has failed." : "L'aggiornamento della nota {id} non è riuscito.",
    "Renaming note {id} has failed." : "La rinomina della nota {id} non è riuscita.",
    "Creating new note has failed." : "Creazione nuova nota non riuscita.",
    "Saving note {id} has failed." : "Il salvataggio della nota {id} non è riuscito.",
    "Updating title for note {id} has failed." : "L'aggiornamento del titolo per la nota {id} non è riuscito.",
    "Undo delete has failed for note {title}." : "Annullamento eliminazione non riuscito per la nota {title}.",
    "Deleting note {id} has failed." : "Eliminazione della nota {id} non riuscita.",
    "Toggling favorite for note {id} has failed." : "L'attivazione come preferito della nota {id} non è riuscita",
    "Updating the note's category has failed. Is the target directory writable?" : "L'aggiornamento della categoria delle note non è riuscito. La cartella di destinazione è scrivibile?",
    "Updating the category for note {id} has failed." : "Aggiornamento della categoria per la nota {id} non riuscito.",
    "Development Mode" : "Modalità di sviluppo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembra che l'applicazione delle note sia stata installata da una sorgente di sviluppo. Installala invece dal <a href=\"%1$s\">Negozio delle applicazioni di Nextcloud</a> ufficiale. Se desideri compilare l'applicazione Note in autonomia, segui le <a href=\"%2$s\">istruzioni per sviluppatori</a>"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
