OC.L10N.register(
    "notes",
    {
    "Notes" : "Notizen",
    "Reading notes from filesystem has failed." : "Laden der Notizen vom Dateisystem ist fehlgeschlagen.",
    "Error" : "Fehler",
    "New note" : "Neue Notiz",
    "Distraction-free notes and writing" : "Ablenkungsfreie Notizen und Schreiben",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Die Notes-App ist eine leicht zu bedienende App zum Erstellen von Notizen in der [Nextcloud](https://www.nextcloud.com/). Zur besseren Übersicht bietet diese die Möglichkeit zur Einordnung der Notizen in Kategorien. Für die Formatierung wird [Markdown](https://en.wikipedia.org/wiki/Markdown) unterstützt. Notizen werden als Dateien in der Nextcloud abgelegt. So kann diese mit jedem Nextcloud-Client bearbeitet werden. Des Weiteren erlaubt eine separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) die einfache Integration in Drittanbieter-Apps (aktuell gibt es Notes-Apps für [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) und die [Konsole](https://git.danielmoch.com/nncli/file/README.rst.html) welche bequemen Zugang zu den Notizen in der Nextcloud erlauben). Weitere Funktionen ermöglichen es unter anderem Notizen als Favoriten zu markieren.",
    "Please see Nextcloud server log for details." : "Für Details siehe Protokolldatei des Nextcloud-Servers.",
    "Deleted {title}" : "{title} gelöscht",
    "Undo Delete" : "Wiederherstellen",
    "Note recovered" : "Notiz wiederhergestellt",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Es existieren nicht-gespeicherte Notizen. Beim Verlassen der Seite gehen alle Änderungen verloren!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} Notiz gelöscht","{number} Notizen gelöscht"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} Notiz wiederhergestellt","{number} Notizen wiederhergestellt"],
    "Notes settings" : "Notizen-Einstellungen",
    "Folder to store your notes" : "Ordner zum Speichern deiner Notizen",
    "Root directory" : "Hauptverzeichnis",
    "File extension for new notes" : "Dateiendung für neue Notizen",
    "Display mode for notes" : "Anzeigemodus für Notizen",
    "User defined" : "Benutzerdefiniert",
    "Open in edit mode" : "Im Bearbeitungsmodus öffnen",
    "Open in preview mode" : "Im Vorschaumodus öffnen",
    "No notes yet" : "Noch keine Notizen vorhanden",
    "Upload image" : "Bild hochladen",
    "Insert image" : "Bild einfügen",
    "Select an image" : "Ein Bild auswählen",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Du kannst keine Bilder außerhalb deines Notizenordners auswählen. Dein Notizenordner ist: {folder}",
    "Wrong image" : "Falsches Bild",
    "The file was not uploaded. Check your server logs." : "Die Datei wurde nicht hochgeladen. Überprüfe deine Serverprotokolle.",
    "All notes" : "Alle Notizen",
    "Categories" : "Kategorien",
    "Loading …" : "Lade …",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "This week" : "Diese Woche",
    "Last week" : "Letzte Woche",
    "This month" : "Dieser Monat",
    "Last month" : "Letzter Monat",
    "Rename" : "Umbenennen",
    "Note's title" : "Titel der Notiz",
    "Delete note" : "Notiz löschen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu Favoriten hinzufügen",
    "Error during preparing note for deletion." : "Fehler beim Vorbereiten der Notiz für die Löschung.",
    "The note has been changed in another session. Please choose which version should be saved." : "Die Notiz wurde in einer anderen Sitzung geändert. Bitte wähle aus, welche Version gespeichert werden soll.",
    "Use version from server" : "Version vom Server verwenden",
    "Use current version" : "Verwende die aktuelle Version",
    "Empty note" : "Leere Notiz",
    "Write …" : "Schreiben …",
    "Details" : "Details",
    "CTRL + /" : "STRG + /",
    "Edit" : "Bearbeiten",
    "Preview" : "Vorschau",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Note is read-only. You cannot change it." : "Notiz ist schreibgeschützt. Du kannst sie nicht ändern.",
    "Save failed. Click to retry." : "Speichern fehlgeschlagen. Klicken um es erneut zu versuchen.",
    "Update conflict. Click for resolving manually." : "Aktualisierungskonflikt. Bitte klicken um den Konflikt manuell zu lösen.",
    "Error from Nextcloud server: {msg}" : "Fehler vom Nextcloud-Server: {msg}",
    "Set category" : "Kategorie ändern",
    "Category" : "Kategorie",
    "Uncategorized" : "Ohne Kategorie",
    "Click here to save manually" : "Hier Klicken um manuell zu speichern",
    "Saving failed!" : "Speichern fehlgeschlagen!",
    "Last modified: {date}" : "Zuletzt geändert: {date}",
    "Note has unsaved changes" : "Notiz enthält nicht gespeicherte Änderungen",
    "Subcategory" : "Unterkategorie",
    "_%n word_::_%n words_" : ["%n Wort","%n Wörter"],
    "_%n character_::_%n characters_" : ["%n Zeichen","%n Zeichen"],
    "Write down your thoughts without any distractions." : "Schreibe deine Gedanken ohne jegliche Störungen auf.",
    "Use Markdown markups to style your text." : "Verwende Markdown um deinen Text zu gestalten.",
    "Organize your notes in categories." : "Sortiere deine Notizen in Kategorien.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installiere die mobile App, um deine Notizen von überall zu nutzen.",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Erstelle eine Notiz per Klick auf „{newnote}“ in der App-Navigation.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kannst Unterkategorien erstellen, indem du „/“ als Trennung zwischen Ober- und Unterkategorie verwendest, z. B. „{parent}/{sub}“.",
    "Note not found." : "Notiz nicht gefunden.",
    "Note is locked." : "Notiz ist gesperrt.",
    "Insufficient storage." : "Speicherplatz nicht ausreichend.",
    "See JavaScript console and server log for details." : "Siehe JavaScript-Konsole und Server-Protokoll für Details.",
    "Updating settings has failed." : "Aktualisierung der Einstellungen fehlgeschlagen.",
    "Fetching notes for dashboard has failed." : "Laden der Notizen für das Dashboard ist fehlgeschlagen.",
    "Fetching notes has failed." : "Laden der Notizen fehlgeschlagen.",
    "Fetching note {id} has failed." : "Abruf der Notiz {id} fehlgeschlagen.",
    "Refreshing note {id} has failed." : "Aktualisieren der Notiz {id} fehlgeschlagen.",
    "Renaming note {id} has failed." : "Umbenennen der Notiz {id} fehlgeschlagen.",
    "Creating new note has failed." : "Erstellen der neuen Notiz fehlgeschlagen.",
    "Saving note {id} has failed." : "Speichern der Notiz {id} fehlgeschlagen.",
    "Updating title for note {id} has failed." : "Ändern des Titels für Notiz {id} fehlgeschlagen.",
    "Undo delete has failed for note {title}." : "Fehler beim Wiederherstellen der Notiz {title}.",
    "Deleting note {id} has failed." : "Löschen der Notiz {id} fehlgeschlagen.",
    "Toggling favorite for note {id} has failed." : "Setzen der Notiz {id} als Favorit fehlgeschlagen.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualisierung der Notizen-Kategorie ist gescheitert. Bestehen Schreibrechte für das Zielverzeichnis?",
    "Updating the category for note {id} has failed." : "Ändern der Kategorie für Notiz {id} fehlgeschlagen.",
    "Development Mode" : "Entwickler-Modus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Es scheint, dass die Notizen-App von einer Entwickler-Quelle installiert wurde. Bitte installiere sie stattdessen von dem offiziellen <a href=\"%1$s\">Nextcloud-App-Store</a>. Wenn du die Notizen-App selbst erstellen möchtest, folge bitte den <a href=\"%2$s\">Entwickler-Anleitungen</a>."
},
"nplurals=2; plural=(n != 1);");
