OC.L10N.register(
    "notes",
    {
    "Notes" : "Catatan",
    "Error" : "Kesalahan",
    "New note" : "Catatan baru",
    "No notes yet" : "Belum ada catatan",
    "All notes" : "Semua catatan",
    "Categories" : "Kategori",
    "Today" : "Hari ini",
    "Yesterday" : "Kemarin",
    "This week" : "Pekan ini",
    "This month" : "Bulan ini",
    "Rename" : "Ubah nama",
    "Delete note" : "Hapus catatan",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "Details" : "Detil",
    "Edit" : "Sunting",
    "Preview" : "Pratinjau",
    "Category" : "Kategori",
    "_%n word_::_%n words_" : ["%n kata"],
    "Android app" : "Aplikasi Android",
    "iOS app" : "Aplikasi iOS"
},
"nplurals=1; plural=0;");
