OC.L10N.register(
    "notes",
    {
    "Notes" : "Jegyzetek",
    "Reading notes from filesystem has failed." : "A jegyzetek olvasása a fájlrendszerről sikertelen.",
    "Error" : "Hiba",
    "New note" : "Új jegyzet",
    "Distraction-free notes and writing" : "Figyelemelterelés nélküli jegyzetelés és írás",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "A Jegyzetek alkalmazás egy figyelemelterelés-mentes jegyzetelő alkalmazás a [Nextcloudhoz](https://www.nextcloud.com/). Kategóriákat biztosít a jobb rendszerezéshez, és támogatja a [Markdown](https://en.wikipedia.org/wiki/Markdown) szintaxisú formázással. A jegyzeteket fájlként menti a Nextcloud, így megtekintheti és szerkesztheti őket bármely Nextcloud klienssel. Ezenkívül egy külön [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) lehetővé teszi az egyszerű integrációt harmadik felek alkalmazásaiba (jelenleg [Androidra](https://github.com/stefan-niedermann/nextcloud-notes), [iOS-re](https://github.com/owncloud/notes-iOS-App) és [konzolhoz] (https: //git.danielmoch.com/nncli/about) vannak jegyzet alkalmazások, melyek kényelmes hozzáférést biztosítanak a nextcloudos jegyzeteihez). A további funkciók közé tartozik a jegyzetek kedvencként való megjelölése.",
    "Please see Nextcloud server log for details." : "További részletekért tekintse meg a Nextcloud kiszolgálónaplóját.",
    "Deleted {title}" : "{title} törölve",
    "Undo Delete" : "Törlés visszavonása",
    "Note recovered" : "Jegyzet helyreállítva",
    "There are unsaved notes. Leaving the page will discard all changes!" : "El nem mentett jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} jegyzet törölve","{number} jegyzet törölve"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} jegyzet helyreállítva","{number} jegyzet helyreállítva"],
    "Notes settings" : "Jegyzetek beállításai",
    "Folder to store your notes" : "Jegyzetek tárolási mappája",
    "Root directory" : "Gyökérkönyvtár",
    "File extension for new notes" : "Új jegyzetek fájlkiterjesztése",
    "Display mode for notes" : "Jegyzetek megjelenítési módja",
    "User defined" : "Felhasználó által megadott",
    "Open in edit mode" : "Megnyitás szerkesztési módban",
    "Open in preview mode" : "Megnyitás előnézeti módban",
    "No notes yet" : "Még nincsenek jegyzetek",
    "Upload image" : "Kép feltöltése",
    "Insert image" : "Kép beszúrása",
    "Select an image" : "Válasszon képet",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nem választhat a jegyzeteken mappán kívül lévő képet. Az Ön jegyzetek mappája: {folder}",
    "Wrong image" : "Hibás kép",
    "The file was not uploaded. Check your server logs." : "A fájl nem lett feltöltve. Nézze meg a kiszolgálónaplókat.",
    "All notes" : "Összes jegyzet",
    "Categories" : "Kategóriák",
    "Loading …" : "Betöltés…",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "This week" : "Ez a hét",
    "Last week" : "Előző hét",
    "This month" : "Ez a hónap",
    "Last month" : "Előző hónap",
    "Rename" : "Átnevezés",
    "Note's title" : "Jegyzet címe",
    "Delete note" : "Jegyzet törlése",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "Error during preparing note for deletion." : "Hiba történt a jegyzettörlésre felkészülés során.",
    "The note has been changed in another session. Please choose which version should be saved." : "A jegyzet egy másik munkamenetben megváltozott. Válasszon, hogy melyik verzió legyen mentve.",
    "Use version from server" : "Kiszolgáló változatának használata",
    "Use current version" : "Jelenlegi verzió használata",
    "Empty note" : "Üres jegyzet",
    "Write …" : "Írás…",
    "Details" : "Részletek",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Szerkesztés",
    "Preview" : "Előnézet",
    "Exit full screen" : "Kilépés a teljes képernyőből",
    "Full screen" : "Teljes képernyő",
    "Note is read-only. You cannot change it." : "A jegyzet írásvédett. Nem változtathat rajta.",
    "Save failed. Click to retry." : "A mentés sikertelen. Próbálja újra.",
    "Update conflict. Click for resolving manually." : "Frissítési ütközés. Kattintson ide a probléma kézi megoldásához.",
    "Error from Nextcloud server: {msg}" : "Nextcloud kiszolgálói hiba: {msg}",
    "Set category" : "Kategória beállítása",
    "Category" : "Kategória",
    "Uncategorized" : "Kategorizálatlan",
    "Click here to save manually" : "Kattintson ide a kézi mentéshez",
    "Saving failed!" : "Mentés sikertelen!",
    "Last modified: {date}" : "Utoljára módosítva: {date}",
    "Note has unsaved changes" : "A jegyzet el nem mentett módosításokat tartalmaz",
    "Subcategory" : "Alkategória",
    "_%n word_::_%n words_" : ["%n szó","%n szó"],
    "_%n character_::_%n characters_" : ["%n karakter","%n karakter"],
    "Write down your thoughts without any distractions." : "Írd le a gondolatait, zavaró tényezők nélkül.",
    "Use Markdown markups to style your text." : "Használjon Markdown leírást a szövege formázásához.",
    "Organize your notes in categories." : "Rendezze kategóriákba a jegyzeteit.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Töltse le az alkalmazást a telefonjára, hogy bárhonnan hozzáférhessen a jegyzeteihez.",
    "Android app" : "Androidos alkalmazás",
    "iOS app" : "iOS-es alkalmazás",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Kezdjen el egy jegyzetet írni a „{newnote}” gombra kattintva a főmenüben.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Alkategóriákat úgy hozhat létre, hogy a „/” karakterrel választja el a szülőkategóriát és az alkategóriát, például „{parent}/{sub}”.",
    "Note not found." : "A jegyzet nem található.",
    "Note is locked." : "A jegyzet zárolva van.",
    "Insufficient storage." : "Nincs elegendő tárhely a mentéshez.",
    "See JavaScript console and server log for details." : "További a részletekért nézze meg a JavaScript konzolt és a kiszolgálónaplót.",
    "Updating settings has failed." : "A beállítások frissítése sikertelen.",
    "Fetching notes for dashboard has failed." : "Az irányítópult jegyzeteinek lekérése sikertelen.",
    "Fetching notes has failed." : "A jegyzetek lekérése sikertelen.",
    "Fetching note {id} has failed." : "A(z) {id} jegyzet lekérése sikertelen.",
    "Refreshing note {id} has failed." : "A(z) {id} jegyzet újratöltése sikertelen.",
    "Renaming note {id} has failed." : "A(z) {id} jegyzet átnevezése sikertelen.",
    "Creating new note has failed." : "Új jegyzet létrehozása sikertelen.",
    "Saving note {id} has failed." : "A(z) {id} jegyzet mentése sikertelen.",
    "Updating title for note {id} has failed." : "A(z) {id} jegyzet címének frissítése sikertelen.",
    "Undo delete has failed for note {title}." : "A(z) {title} jegyzet törlésének visszavonása sikertelen.",
    "Deleting note {id} has failed." : "A(z) {id} jegyzet törlése sikertelen.",
    "Toggling favorite for note {id} has failed." : "A(z) {id} jegyzet hozzáadása a kedvencekhez sikertelen.",
    "Updating the note's category has failed. Is the target directory writable?" : "A jegyzet kategóriájának frissítése sikertelen. Írható a célkönyvtár?",
    "Updating the category for note {id} has failed." : "A jegyzet kategóriájának módosítása sikertelen.",
    "Development Mode" : "Fejlesztői mód",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Úgy tűnik, hogy a Jegyzetek alkalmazást fejlesztői forrásból telepítették. Inkább telepítse a hivatalos <a href=\"%1$s\">Nextcloud alkalmazástárból </a>. Ha Ön szeretné összeállítani a Jegyzetek alkalmazást, akkor kövesse a <a href=\"%2$s\">fejlesztői utasításokat</a>."
},
"nplurals=2; plural=(n != 1);");
