OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "Error",
    "New note" : "New note",
    "Distraction-free notes and writing" : "Distraction-free notes and writing",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favourites.",
    "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
    "Display mode for notes" : "Display mode for notes",
    "Open in edit mode" : "Open in edit mode",
    "Open in preview mode" : "Open in preview mode",
    "No notes yet" : "No notes yet",
    "All notes" : "All notes",
    "Categories" : "Categories",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "This week" : "This week",
    "This month" : "This month",
    "Rename" : "Rename",
    "Delete note" : "Delete note",
    "Remove from favorites" : "Remove from favourites",
    "Add to favorites" : "Add to favourites",
    "Error during preparing note for deletion." : "Error while preparing note for deletion.",
    "Details" : "Details",
    "Edit" : "Edit",
    "Preview" : "Preview",
    "Category" : "Category",
    "Uncategorized" : "Uncategorised",
    "Saving failed!" : "Saving failed!",
    "_%n word_::_%n words_" : ["%n word","%n words"],
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Toggling favorite for note {id} has failed." : "Toggling favourite for note {id} has failed."
},
"nplurals=2; plural=(n != 1);");
