OC.L10N.register(
    "notes",
    {
    "Notes" : "Нотатки",
    "Reading notes from filesystem has failed." : "Не вдалося прочитати нотатки з файлової системи.",
    "Error" : "Помилка",
    "New note" : "Нова нотатка",
    "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Програма Notes – це програма для створення нотаток для [Nextcloud](https://www.nextcloud.com/), яка не відволікається. Він надає категорії для кращої організації та підтримує форматування за допомогою синтаксису [Markdown](https://en.wikipedia.org/wiki/Markdown). Нотатки зберігаються як файли у вашому Nextcloud, тож ви можете переглядати та редагувати їх у кожному клієнті Nextcloud. Крім того, окремий [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) дозволяє легко інтегрувати програми сторонніх розробників (наразі існують програми для нотаток). для [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) і [консолі](https: //git.danielmoch.com/nncli/about), що забезпечує зручний доступ до ваших нотаток Nextcloud). Інші функції включають позначення нотаток як вибраних.",
    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера Nextcloud для отримання додаткової інформації.",
    "Deleted {title}" : "Вилучено {title}",
    "Undo Delete" : "Повернути вилучення",
    "Note recovered" : "Примітку відновлено",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Видалено {number} примітка","Видалено {number} приміток","Видалено {number} приміток","Видалено {number} приміток"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатка","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
    "Notes settings" : "Налаштування",
    "Folder to store your notes" : "Каталог для збереження нотаток",
    "Root directory" : "Кореневий каталог",
    "File extension for new notes" : "Розширення файлу для нових нотаток",
    "Display mode for notes" : "Показувати нотатки",
    "User defined" : "Визначений користувачем",
    "Open in edit mode" : "Відкривати у режимі редагування",
    "Open in preview mode" : "Відкривати у режимі перегляду",
    "No notes yet" : "Нотатки поки відсутні",
    "Upload image" : "Завантажити зображення",
    "Insert image" : "Додати зображення",
    "Select an image" : "Виберіть зображення",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ви не можете вибрати зображення за межами каталогу з нотатками. Ваш каталог нотаток: {folder}",
    "Wrong image" : "Невірне зображення",
    "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали свого сервера.",
    "All notes" : "Усі нотатки",
    "Categories" : "Категорії",
    "Loading …" : "Завантаження...",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "This week" : "Цього тижня",
    "Last week" : "Минулого тижня",
    "This month" : "Цього місяця",
    "Last month" : "Минулого місяця",
    "Rename" : "Перейменувати",
    "Note's title" : "Назва нотатки",
    "Delete note" : "Вилучити нотатку",
    "Remove from favorites" : "Вилучено з улюбленого",
    "Add to favorites" : "Додати до улюбленого",
    "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
    "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
    "Use version from server" : "Використовуйте версію з сервера",
    "Use current version" : "Використовувати поточну версію",
    "Empty note" : "Порожня записка",
    "Write …" : "Напишіть…",
    "Details" : "Деталі",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Редашувати",
    "Preview" : "Перегляд",
    "Exit full screen" : "Вийти з повноекранного режиму",
    "Full screen" : "Повноекранний режим",
    "Note is read-only. You cannot change it." : "Примітка доступна лише для читання. Ви не можете це змінити.",
    "Save failed. Click to retry." : "Не вдалося зберегти. Натисніть, щоб повторити спробу.",
    "Update conflict. Click for resolving manually." : "Конфлікт оновлень. Натисніть, щоб вирішити вручну.",
    "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
    "Category" : "Категорія",
    "Uncategorized" : "Некатегоризоване",
    "Set category" : "Встановити категорію",
    "Click here to save manually" : "Натисніть тут, щоб зберегти вручну",
    "Saving failed!" : "Не вдалося зберегти!",
    "Last modified: {date}" : "Остання зміна: {дата}",
    "Note has unsaved changes" : "Примітка містить незбережені зміни",
    "Subcategory" : "Підкатегорія",
    "_%n word_::_%n words_" : ["%n слово","%n слів","%n слів","%n слів"],
    "_%n character_::_%n characters_" : ["%n персонаж","%n персонажів","%n персонажів","%n персонажів"],
    "Write down your thoughts without any distractions." : "Записуйте свої думки, не відволікаючись.",
    "Use Markdown markups to style your text." : "Використовуйте розмітку Markdown, щоб стилізувати текст.",
    "Organize your notes in categories." : "Упорядкуйте свої нотатки за категоріями.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть програму для свого мобільного телефону, щоб мати доступ до своїх нотаток звідусіль.",
    "Android app" : "Застосунок для Android",
    "iOS app" : "Застосунок для iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, натиснувши «{newnote}» ​​у навігаційній панелі програми.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Ви можете створювати підкатегорії, використовуючи «/» як роздільник між батьківською категорією та підкатегорією, наприклад. “{parent}/{sub}”.",
    "Note not found." : "Примітка не знайдена.",
    "Note is locked." : "Примітка заблокована.",
    "Insufficient storage." : "Недостатньо місця для зберігання.",
    "See JavaScript console and server log for details." : "Додаткову інформацію див. у консолі JavaScript і журналі сервера.",
    "Updating settings has failed." : "Не вдалося оновити налаштування.",
    "Fetching notes for dashboard has failed." : "Не вдалося отримати нотатки для інформаційної панелі.",
    "Fetching notes has failed." : "Помилка отримання нотаток.",
    "Fetching note {id} has failed." : "Не вдалося отримати нотатку {id}.",
    "Refreshing note {id} has failed." : "Не вдалося оновити нотатку {id}.",
    "Renaming note {id} has failed." : "Не вдалося перейменувати нотатку {id}.",
    "Creating new note has failed." : "Не вдалося створити нотатку.",
    "Saving note {id} has failed." : "Не вдалося зберегти нотатку {id}.",
    "Updating title for note {id} has failed." : "Помилка оновлення назви нотатки {id}.",
    "Undo delete has failed for note {title}." : "Не вдалося скасувати вилучення нотатки {title}.",
    "Deleting note {id} has failed." : "Не вдалося вилучити нотатку {id}.",
    "Toggling favorite for note {id} has failed." : "Помилка перемикання вподобань для нотатки {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Не вдалося оновити категорію нотатки. Чи доступний цільовий каталог для запису?",
    "Updating the category for note {id} has failed." : "Не вдалося оновити категорію для примітки {id}.",
    "Development Mode" : "Режим розробки",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Схоже, застосунок для нотаток було встановлено з джерела розробки. Установіть його з офіційного <a href=\"%1$s\">каталогу застосунків Nextcloud</a>. Якщо ви хочете збілдити застосунок \"Нотатки\" самостійно, дотримуйтесь <a href=\"%2$s\">інструкцій розробника</a>."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
