OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Reading notes from filesystem has failed." : "Erro ao ler anotações do sistema de arquivos.",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Distraction-free notes and writing" : "Notas e escrita sem distração",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "O aplicativo Notes é um aplicativo de anotações livre de distrações para o [Nextcloud](https://www.nextcloud.com/). Suporta categorias para uma melhor organização e formatação usando a sintaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). As notas são salvas como arquivos em seu Nextcloud, para que você possa visualizá-las e editá-las com qualquer cliente Nextcloud. Além disso, uma [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) separada permite uma fácil integração com aplicativos de terceiros (atualmente, há aplicativos de notas para [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) e [console](https://git.danielmoch.com/nncli/about) que permitem acesso conveniente às suas anotações do Nextcloud). Recursos futuros permitirão marcar notas como favoritos.",
    "Please see Nextcloud server log for details." : "Verifique os logs do servidor Nextcloud para detalhes.",
    "Deleted {title}" : "{title} excluído",
    "Undo Delete" : "Desfazer Exclusão",
    "Note recovered" : "Nota recuperada",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Existem anotações não salvas. Saindo da página elas serão perdidas!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} nota apagada","{number} notas apagadas","{number} notas apagadas"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} nota recuperada","{number} notas recuperadas","{number} notas recuperadas"],
    "Notes settings" : "Configurações de notas",
    "Folder to store your notes" : "Pasta para armazenar anotações",
    "Root directory" : "Diretório raiz",
    "File extension for new notes" : "Extensão para novas anotações",
    "Display mode for notes" : "Modo de exibição para notas",
    "User defined" : "Usuário definido",
    "Open in edit mode" : "Abra no modo de edição",
    "Open in preview mode" : "Abrir no modo de visualização",
    "No notes yet" : "Nenhuma nota ainda",
    "Upload image" : "Enviar Imagem",
    "Insert image" : "Inserir Imagem",
    "Select an image" : "Selecione uma imagem",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Você não pode selecionar imagens fora de sua pasta de notas. Sua pasta de notas é: {folder}",
    "Wrong image" : "Imagem errada",
    "The file was not uploaded. Check your server logs." : "O arquivo não foi carregado. Verifique os logs do seu servidor.",
    "All notes" : "Todas as notas",
    "Categories" : "Categorias",
    "Loading …" : "Carregando...",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "This week" : "Esta semana",
    "Last week" : "Última semana",
    "This month" : "Este mês",
    "Last month" : "Último mês",
    "Rename" : "Renomear",
    "Note's title" : "Título da anotação",
    "Delete note" : "Excluir anotação",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Error during preparing note for deletion." : "Erro ao preparar anotação para exclusão.",
    "The note has been changed in another session. Please choose which version should be saved." : "A nota foi alterada em outra sessão. Escolha qual versão deve ser salva.",
    "Use version from server" : "Use a versão do servidor",
    "Use current version" : "Use a versão atual",
    "Empty note" : "Anotação vazia",
    "Write …" : "Escrever...",
    "Details" : "Detalhes",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Preview" : "Pré-visualização",
    "Exit full screen" : "Sair da tela inteira",
    "Full screen" : "Tela inteira",
    "Note is read-only. You cannot change it." : "Esta nota é apenas para leitura. Você não pode mudá-la.",
    "Save failed. Click to retry." : "Falha ao salvar. Clique para retentar.",
    "Update conflict. Click for resolving manually." : "Conflito de atualização. Clique para resolver manualmente.",
    "Error from Nextcloud server: {msg}" : "Erro do servidor Nextcloud: {msg}",
    "Set category" : "Definir categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Sem categoria",
    "Click here to save manually" : "Clique aqui para salvar manualmente",
    "Saving failed!" : "Gravação falhou!",
    "Last modified: {date}" : "Última modificação: {date}",
    "Note has unsaved changes" : "A anotação tem alterações não salvas",
    "Subcategory" : "Subcategoria",
    "_%n word_::_%n words_" : ["%n palavra","%n palavras","%n palavras"],
    "_%n character_::_%n characters_" : ["%n caractere","%n caracteres","%n caracteres"],
    "Write down your thoughts without any distractions." : "Anote seus pensamentos sem distrações.",
    "Use Markdown markups to style your text." : "Use marcações Markdown para estilizar seu texto.",
    "Organize your notes in categories." : "Organize suas anotações em categorias.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instale o aplicativo em seu celular para acessar anotações a partir de qualquer lugar.",
    "Android app" : "Aplicativo Android",
    "iOS app" : "Aplicativo iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comece a escrever uma anotação clicando em “{newnote}” na navegação do aplicativo.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Você pode criar subcategorias usando “/” como delimitador entre categoria pai e subcategoria, por.ex. “{parent}/{sub}”.",
    "Note not found." : "Anotação não encontrada.",
    "Note is locked." : "A anotação está bloqueada.",
    "Insufficient storage." : "Armazenamento insuficiente.",
    "See JavaScript console and server log for details." : "Veja o console JavaScript console e os logs do servidor para detalhes.",
    "Updating settings has failed." : "A atualização das configurações falhou.",
    "Fetching notes for dashboard has failed." : "A obtenção de notas para o painel falhou.",
    "Fetching notes has failed." : "A busca de anotações falhou.",
    "Fetching note {id} has failed." : "A busca da anotação {id} falhou.",
    "Refreshing note {id} has failed." : "Erro na atualização da anotação {id}.",
    "Renaming note {id} has failed." : "Erro ao renomear a anotação {id}.",
    "Creating new note has failed." : "A criação de uma nova anotação falhou.",
    "Saving note {id} has failed." : "Erro ao salvar a nota {id}.",
    "Updating title for note {id} has failed." : "A atualização do título para a anotação {id} falhou.",
    "Undo delete has failed for note {title}." : "Erro ao desfazer exclusão da anotação {title}.",
    "Deleting note {id} has failed." : "A exclusão da anotação {id} falhou.",
    "Toggling favorite for note {id} has failed." : "A alternância de favoritos para a anotação {id} falhou.",
    "Updating the note's category has failed. Is the target directory writable?" : "A atualização da categoria da nota falhou. O diretório de destino é gravável?",
    "Updating the category for note {id} has failed." : "A atualização da categoria da anotação {id} falhou.",
    "Development Mode" : "Modo de Desenvolvimento",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que o aplicativo Notes foi instalado a partir de uma fonte de desenvolvimento. Ao invés disso, instale-o a partir da <a href=\"%1$s\">Loja de Aplicativos Nextcloud</a> oficial. Se deseja criar o aplicativo Notes você mesmo, siga as <a href=\"%2$s\">instruções do desenvolvedor</a>."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
