OC.L10N.register(
    "notes",
    {
    "Notes" : "Белешке",
    "Reading notes from filesystem has failed." : "Читање белешки са система фајлова није успело.",
    "Error" : "Грешка",
    "New note" : "Нова белешка",
    "Distraction-free notes and writing" : "Белешке и писање без ометања",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Апликација Белешки је апликација за хватање белешки без ометања за [Некстклауд](https://www.nextcloud.com/).. Подржава [Markdown](https://en.wikipedia.org/wiki/Markdown) синтаксу. Белешке се чувају као фајлови у Некстклауду, тако да их можете видети и мењати са сваким Некстклауд клијентом. Такође, посебан [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) дозвољава лаку интеграцију са апликацијама треће стране (тренутно постоји апликација белешку за [Андроид](https://github.com/stefan-niedermann/nextcloud-notes), за [iOS](https://github.com/owncloud/notes-iOS-App) и [конзолу](https://git.danielmoch.com/nncli/about) које дозвољавају једноставан приступ Некстклауд белешкама). Такође, белешке можете означавати као омиљене.",
    "Please see Nextcloud server log for details." : "Погледајте Некстклауд серверске логове за детаље.",
    "Deleted {title}" : "Обрисана {title}",
    "Undo Delete" : "Опозови брисање",
    "Note recovered" : "Белешка опорављена",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има несачуваних белешки. Напуштањем стране ћете поништити све измене!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Обрисано {number} белешка","Обрисано {number} белешке","Обрисано {number} белешки"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Опорављено {number} белешка","Опорављено {number} белешке","Опорављено {number} белешки"],
    "Folder to store your notes" : "Фасцикла за складиштење белешки",
    "File extension for new notes" : "Екстензија фајлова код нових белешки",
    "Display mode for notes" : "Режим приказа белешки",
    "Open in edit mode" : "Отвори у режиму уређивања",
    "Open in preview mode" : "Отвори у режиму прегледа",
    "No notes yet" : "Још нема белешки",
    "Insert image" : "Убаци слику",
    "All notes" : "Све белешке",
    "Categories" : "Категорије",
    "Loading …" : "Учитавање…",
    "Today" : "Данас",
    "Yesterday" : "Јуче",
    "This week" : "Ове недеље",
    "Last week" : "Прошле недеље",
    "This month" : "Овог месеца",
    "Last month" : "Прошлог месеца",
    "Rename" : "Преименуј",
    "Note's title" : "Наслов белешке",
    "Delete note" : "Обриши белешку",
    "Remove from favorites" : "Уклони из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Error during preparing note for deletion." : "Грешка приликом припремања белешке за брисање.",
    "Use current version" : "Користи тренутну верзију",
    "Empty note" : "Празна белешка",
    "Write …" : "Пиши…",
    "Details" : "Детаљи",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Измени",
    "Preview" : "Претпреглед",
    "Exit full screen" : "Напусти цео екран",
    "Full screen" : "Цео екран",
    "Save failed. Click to retry." : "Грешка при чувању. Кликните да покушате поново.",
    "Error from Nextcloud server: {msg}" : "Грешка са Некстклауд сервера: {msg}",
    "Set category" : "Одаберите категорију",
    "Category" : "Категорија",
    "Uncategorized" : "Некатегоризовано",
    "Click here to save manually" : "Кликните овде да сачувате ручно",
    "Saving failed!" : "Снимање није успело!",
    "Last modified: {date}" : "Последња измена: {date}",
    "Note has unsaved changes" : "Белешка има несачуваних измена",
    "Subcategory" : "Подкатегорија",
    "_%n word_::_%n words_" : ["%n реч","%n речи","%n речи"],
    "_%n character_::_%n characters_" : ["%n карактер","%n карактера","%n карактера"],
    "Write down your thoughts without any distractions." : "Запишите Ваше мисли без ометања.",
    "Use Markdown markups to style your text." : "Користите Markdown језик да стилизујете текст.",
    "Organize your notes in categories." : "Организујте белешке у категорије.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте апликацију за мобилни да приступите Вашим белешкама где год да се налазите.",
    "Android app" : "Андроид апликација",
    "iOS app" : "iOS апликација",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Крените да пишете белешке кликајући „{newnote}“ из навигације апликације.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да направите подкатегорије користећи „/“ као разграничавач између категорије родитеља и подкатегорије, нпр. „{parent}/{sub}“",
    "Note not found." : "Белешка није нађена.",
    "Note is locked." : "Белешка је закључана.",
    "Insufficient storage." : "Недовољно места.",
    "See JavaScript console and server log for details." : "Погледајте JavaScript конзолу и дневник са сервера за детаље.",
    "Updating settings has failed." : "Ажурирање подешавања није успело.",
    "Fetching notes for dashboard has failed." : "Дохватање белешки за контролну таблу није успело.",
    "Fetching notes has failed." : "Дохватање белешки није успело.",
    "Fetching note {id} has failed." : "Дохватање белешке {id} није успело.",
    "Refreshing note {id} has failed." : "Освежавање белешке {id} није успело.",
    "Renaming note {id} has failed." : "Преименовање белешке {id} није успело.",
    "Creating new note has failed." : "Прављење нове белешке није успело.",
    "Saving note {id} has failed." : "Чување белешке {id} није успело.",
    "Updating title for note {id} has failed." : "Промена наслова белешке {id} није успела.",
    "Undo delete has failed for note {title}." : "Опозивање брисања није успело за белешку {title}.",
    "Deleting note {id} has failed." : "Брисање белешке {id} није успело.",
    "Toggling favorite for note {id} has failed." : "Стављање/уклањање омиљене белешке {id} није успело.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање категорије белешке. Да ли у одредишни директоријум може да се пише?",
    "Updating the category for note {id} has failed." : "Ажурирање категорије белешке {id} није успело.",
    "Development Mode" : "Развојни режим",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Изгледа да је апликација белешки инсталирана из развојног извора. Молимо да је инсталирате из званичне <a href=\"%1$s\">Некстклауд продавнице</a>. Ако желите само да искомпајлирате апликацију Белешки, пратите <a href=\"%2$s\">инструкције за програмере</a>."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
