OC.L10N.register(
    "notes",
    {
    "Notes" : "บันทึกย่อ",
    "Error" : "ข้อผิดพลาด",
    "New note" : "สร้างบันทึกใหม่",
    "Display mode for notes" : "โหมดแสดงผลสำหรับโน้ต",
    "Open in edit mode" : "เปิดในโหมดแก้ไข",
    "Open in preview mode" : "เปิดในโหมดแสดงตัวอย่าง",
    "All notes" : "โน้ตทั้งหมด",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "This week" : "สัปดาห์นี้",
    "Last week" : "สัปดาห์ที่แล้ว",
    "This month" : "เดือนนี้",
    "Last month" : "เดือนที่แล้ว",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete note" : "ลบบันทึกย่อ",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Details" : "รายละเอียด",
    "Edit" : "แก้ไข",
    "Preview" : "ตัวอย่าง",
    "Category" : "หมวดหมู่",
    "Uncategorized" : "ไม่ได้จัดหมวดหมู่",
    "_%n word_::_%n words_" : ["%n คำ"],
    "Android app" : "แอพฯ แอนดรอยด์",
    "iOS app" : "แอพฯ IOS"
},
"nplurals=1; plural=0;");
