OC.L10N.register(
    "notes",
    {
    "Notes" : "Beležka",
    "Reading notes from filesystem has failed." : "Branje zabeležk z datotečnega sistema je spodletelo.",
    "Error" : "Napaka",
    "New note" : "Nova zabeležka",
    "Distraction-free notes and writing" : "Enostavno beleženje in zapisovanje",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Program Notes je enostaven program za beleženje besedilnih sporočil za [Nextcloud](https://www.nextcloud.com/). Podpira uporabo kategorij za razvrščanje zabeležk in oblikovanje besedila z uporabo skladnje [Markdown](https://en.wikipedia.org/wiki/Markdown). Zabeležke se shranijo kot datoteke v oblaku Nextcloud, zato jih je mogoče pregledovati in urejati z vsemi vrstami urejevalnikov. Program omogoča prek vmesnika [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) enostavno integracijo tudi v programsko opremo tretjih oseb (na voljo je že odjemalec za [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) in [konzolo](https://git.danielmoch.com/nncli/about), kar še dodatno poenostavi dostop). Podprto je tudi označevanje zabeležk kot priljubljenih.",
    "Please see Nextcloud server log for details." : "Za več podrobnosti si oglejte dnevniški zapis strežnika Nextcloud.",
    "Deleted {title}" : "Izbrisano {title}",
    "Undo Delete" : "Razveljavi brisanje",
    "Note recovered" : "Zabeležka je obnovljena",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Zabeležke še niso shranjene. Če zapustite stran, bodo spremembe izgubljene!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Izbrisana je {number} zabeležka.","Izbrisani sta {number} zabeležki.","Izbrisane so {number} zabeležke.","Izbrisanih je {number} zabeležk."],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Obnovljena je {number} zabeležka.","Obnovljeni sta {number} zabeležki.","Obnovljene so {number} zabeležke.","Obnovljenih je {number} zabeležk."],
    "Notes settings" : "Nastavitve beležk",
    "Folder to store your notes" : "Mapa za shranjevanje zabeležk",
    "Root directory" : "Korenska mapa",
    "File extension for new notes" : "Privzeta pripona datotek za nove zabeležke",
    "Display mode for notes" : "Način prikaza zabeležk",
    "User defined" : "Uporabniško določeno",
    "Open in edit mode" : "Zabeležka se odpre v urejevalnem načinu",
    "Open in preview mode" : "Zabeležka se odpre v predogledu",
    "No notes yet" : "Ni še dodane nobene zabeležke.",
    "Upload image" : "Pošlji sliko",
    "Insert image" : "Vstavi sliko",
    "Select an image" : "Izbor slike",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ni mogoče izbrati slik izven mape beležk. Ustrezna mapa je: {folder}.",
    "Wrong image" : "Napačna slika",
    "The file was not uploaded. Check your server logs." : "Datoteka ni poslana. Več podrobnosti je zapisanih v dnevniškem zapisu strežnika.",
    "All notes" : "Vse zabeležke",
    "Categories" : "Kategorije",
    "Loading …" : "Poteka nalaganje …",
    "Today" : "Danes",
    "Yesterday" : "Včeraj",
    "This week" : "Ta teden",
    "Last week" : "Zadnji teden",
    "This month" : "Ta mesec",
    "Last month" : "Zadnji mesec",
    "Rename" : "Preimenuj",
    "Note's title" : "Naslov zabeležke",
    "Delete note" : "Izbriši beležko",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "Error during preparing note for deletion." : "Prišlo je do napake med pripravo zabeležke za brisanje.",
    "The note has been changed in another session. Please choose which version should be saved." : "Sporočilce je bilo spremenjeno v drugem programo. Izberite, katera različica naj bo shranjena.",
    "Use version from server" : "Uporabi različico s strežnika",
    "Use current version" : "Uporabi trenutno različico",
    "Empty note" : "Prazno sporočilo",
    "Write …" : "Zapisovanje ...",
    "Details" : "Podrobnosti",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Uredi",
    "Preview" : "Predogled",
    "Exit full screen" : "Končaj celozaslonski način",
    "Full screen" : "Celozaslonski način",
    "Note is read-only. You cannot change it." : "Sporočilo je le za branje in ga ni mogoče spreminjati.",
    "Save failed. Click to retry." : "Shranjevanje je spodletelo. Kliknite za ponovni poskus.",
    "Update conflict. Click for resolving manually." : "Zaznan je spor usklajevanja, ki ga je treba razrešiti ročno.",
    "Error from Nextcloud server: {msg}" : "Napaka s strežnika Nextcloud: {msg}",
    "Set category" : "Nastavi kategorijo",
    "Category" : "Kategorija",
    "Uncategorized" : "Neopredeljeno",
    "Click here to save manually" : "Kliknite za ročno shranjevanje",
    "Saving failed!" : "Shranjevanje je spodletelo!",
    "Last modified: {date}" : "Nazadnje spremenjeno: {date}",
    "Note has unsaved changes" : "V beležki so neshranjene spremembe.",
    "Subcategory" : "Podkategorija",
    "_%n word_::_%n words_" : ["%n beseda","%n besedi","%n besede","%n besed"],
    "_%n character_::_%n characters_" : ["%n znak","%n znaka","%nznaki","%n znakov"],
    "Write down your thoughts without any distractions." : "Zapisovanje beležk brez vsakršnih motenj.",
    "Use Markdown markups to style your text." : "Za oblikovanje besedila je mogoče uporabiti jezik Markdown.",
    "Organize your notes in categories." : "Beležke je mogoče razvrstiti v kategorije.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Za dostop do beležk je na voljo tudi program za mobilne naprave.",
    "Android app" : "Odjemalec za Android",
    "iOS app" : "Odjemalec za iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Novo beležko je mogoče začeti s klikom na »{newnote}«.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podrejene kategorije je mogoče ustvariti z uporabo poševnice » / « kot ločila med nadrejeno in podrejeno kategorijo, na primer »{parent}/{sub}«.",
    "Note not found." : "Zabeležke ni mogoče najti",
    "Note is locked." : "Zabeležka je zaklenjena.",
    "Insufficient storage." : "Nezadostna količina prostora.",
    "See JavaScript console and server log for details." : "Več podrobnosti je zbranih v konzoli JavaScript.",
    "Updating settings has failed." : "Posodabljanje nastavitev je spodletelo.",
    "Fetching notes for dashboard has failed." : "Pridobivanje zabeležk za Nadzorno ploščo je spodletelo.",
    "Fetching notes has failed." : "Pridobivanje zabeležk je spodletelo.",
    "Fetching note {id} has failed." : "Pridobivanje določila {id} sporočila je spodletelo.",
    "Refreshing note {id} has failed." : "Osveževanje zabeležke {id} je spodletelo.",
    "Renaming note {id} has failed." : "Preimenovanje zabeležke {id} je spodletelo.",
    "Creating new note has failed." : "Ustvarjanje nove zabeležke je spodletelo.",
    "Saving note {id} has failed." : "Shranjevanje zabeležke {id} je spodletelo.",
    "Updating title for note {id} has failed." : "Posodabljanje naslova zabeležke {id} je spodletelo.",
    "Undo delete has failed for note {title}." : "Razveljavitev brisanja je za zabeležko {title} spodletelo.",
    "Deleting note {id} has failed." : "Brisanje določila {id} sporočila je spodletelo.",
    "Toggling favorite for note {id} has failed." : "Preklop oznake priljubljeno za beležko {id} je spodletelo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Posodabljanje kategorije zabeležke je spodletelo. Ali ima ciljno mesto nastavljena ustrezna dovoljenja za zapisovanje?",
    "Updating the category for note {id} has failed." : "Posodabljanje kategorije za beležko {id} je spodletelo.",
    "Development Mode" : "Razvojni način",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Kaže, da je program nameščen in razvojne različice. Priporočena je namestitev iz uradne trgovine <a href=\"%1$s\">Nextcloud App Store</a>. Seveda lahko program izgradite tudi sami, upoštevajoč <a href=\"%2$s\">navodila za razvijalce</a>."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
