OC.L10N.register(
    "notes",
    {
    "Notes" : "الملاحظات",
    "Error" : "خطأ",
    "New note" : "ملاحظة جديدة ",
    "Display mode for notes" : "وضع العرض للملاحظات",
    "Open in edit mode" : "فتح في وضع التحرير",
    "Open in preview mode" : "فتح في وضع المعاينة",
    "No notes yet" : "لا ملاحظات حاليا",
    "All notes" : "جميع الملاحظات",
    "Categories" : "الفئات",
    "Loading …" : "جاري التحميل …",
    "Today" : "اليوم",
    "Yesterday" : "البارحة",
    "This week" : "هذا الأسبوع",
    "Last week" : "الأسبوع الماضي",
    "This month" : "هذا الشهر",
    "Last month" : "الشهر الماضي",
    "Rename" : "إعادة التسمية",
    "Delete note" : "حذف الملاحظة ",
    "Remove from favorites" : "إزالتها مِن المفضلة",
    "Add to favorites" : "أضفه إلى المفضلة",
    "Details" : "التفاصيل",
    "Edit" : "تعديل",
    "Preview" : "معاينة",
    "Category" : "الفئة",
    "Uncategorized" : "غير مصنف",
    "Saving failed!" : "فشلت عملية الحفظ !",
    "_%n word_::_%n words_" : ["كلمة","كلمة","كلمتان","كلمات","كلمات","كلمات"],
    "Android app" : "تطبيق الأندرويد",
    "iOS app" : "تطبيق آي أواس"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
