OC.L10N.register(
    "notes",
    {
    "Notes" : "Piezīmes",
    "Error" : "Kļūda",
    "New note" : "Jauna piezīme",
    "No notes yet" : "Nav nevienas piezīmes",
    "All notes" : "Visas piezīmes",
    "Categories" : "Kategorijas",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "This week" : "Šonedēļ",
    "This month" : "Šis mēnesis",
    "Rename" : "Pārsaukt",
    "Delete note" : "Dzēst piezīmi",
    "Remove from favorites" : "Noņemt no izlases",
    "Add to favorites" : "Pievienot izlasei",
    "Details" : "Detaļas",
    "Edit" : "Rediģēt",
    "Preview" : "Priekšskatīt",
    "Category" : "Kategorija",
    "Uncategorized" : "Bez kategorijas",
    "_%n word_::_%n words_" : ["%n words","%n vārdi","%n vārdi"],
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
