OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "Reading notes from filesystem has failed." : "Citirea notiţelor din sistemul de fişiere a eşuat.",
    "Error" : "Eroare",
    "New note" : "Notă nouă",
    "Distraction-free notes and writing" : "Scrie notiţe fără a fi distras",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplicaţia Notes este o aplicaţie de notiţe fără alte distracţii, construită pentru [Nextcloud](https://www.nextcloud.com/). Oferă categorii pentru o mai bună organizare şi suportă sintaxa de editare text [Markdown](https://en.wikipedia.org/wiki/Markdown. Notiţele sunt salvate ca şi fişiere pe serverul dumneavoastră Nextcloud, astfel că puteţi să vizualizaţi şi să ştergeţi aceste notiţe de pe orice client Nextcloud. Mai mult un [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) permite o mai bună integrare în aplicaţii terţe (în acest moment există aplicaţii de luat notiţe pentru [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App, şi [CLI](https://git.danielmoch.com/nncli/about). Acestea oferă accest într-un mod convenabil la notiţele tale din Nextcloud). O caracteristică suplimentară include adăugarea notiţelor la o listă de favorite.",
    "Please see Nextcloud server log for details." : "Vă rugăm să verificaţi fişierele log de pe serverul Nextcloud pentru mai multe detalii.",
    "Deleted {title}" : "{title} a fost şters",
    "Undo Delete" : "Anulează ștergerea",
    "Note recovered" : "Notiţa a fost recuperată",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Există notiţe nesalvate. Dacă părăsiţi această pagină aceste schimbări vor fi pierdute!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["A fost şters %1$d notiţă","Au fost şterse %1$d notiţe","Au fost şterse %1$d de notiţe"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["A fost recuperat {number} notiţă","Au fost recuperate {number} notiţe","Au fost recuperate {number} de notiţe"],
    "Folder to store your notes" : "Dosarul pentru a stoca notiţele tale",
    "Root directory" : "Director rădacină",
    "File extension for new notes" : "Extensia fişierului pentru notiţele noi",
    "Display mode for notes" : "Mod afișare notițe",
    "User defined" : "Definit de utilizator",
    "Open in edit mode" : "Deschide în modul editare",
    "Open in preview mode" : "Deschide în modul de previzualizare ",
    "No notes yet" : "Nu există notițe",
    "Upload image" : "Încarcă imagine",
    "Insert image" : "Introdu imagine",
    "Select an image" : "Selectează o imagine",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nu poți selecta imagini din exteriorul dosarului de notițe. Dosarul tău de notițe este: {folder}",
    "Wrong image" : "Imagine greșită",
    "The file was not uploaded. Check your server logs." : "Imaginea nu a fost încărcată. Verifică fișierele log.",
    "All notes" : "Toate notițele",
    "Categories" : "Categorii",
    "Loading …" : "Se încarcă…",
    "Today" : "Azi",
    "Yesterday" : "Ieri",
    "This week" : "Săptămâna asta",
    "Last week" : "Săptămâna trecută ",
    "This month" : "Luna asta",
    "Last month" : "Luna trecută ",
    "Rename" : "Redenumire",
    "Note's title" : "Titlul notiţei",
    "Delete note" : "Şterge nota",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adăugați la favorite",
    "Error during preparing note for deletion." : "A apărut o eroare în timpul pregătirii ştergerii notiţei.",
    "The note has been changed in another session. Please choose which version should be saved." : "Această notiţă a fost schimbată în altă sesiune. Vă rugăm să alegeţi ce versiune să fie salvată.",
    "Use version from server" : "Foloseşte versiunea de pe server",
    "Use current version" : "Folosește versiunea curentă",
    "Empty note" : "Notiţă goală",
    "Write …" : "Scrie ...",
    "Details" : "Detalii",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editează",
    "Preview" : "Previzualizare",
    "Exit full screen" : "Ieşire din modul ecran complet",
    "Full screen" : "Ecran complet",
    "Note is read-only. You cannot change it." : "Notiţa este numai pentru citire. Nu este posibil să o modifici.",
    "Save failed. Click to retry." : "Salvarea a eşuat. Click pentru a reîncerca.",
    "Update conflict. Click for resolving manually." : "Actualizează conflictul. Click pentru a resolva manual această problemă.",
    "Error from Nextcloud server: {msg}" : "Eroare din partea severului Nextcloud: {msg}",
    "Set category" : "Setează categoria",
    "Category" : "Categorie",
    "Uncategorized" : "Fără categorie ",
    "Click here to save manually" : "Apasă aici pentru a salva manual",
    "Saving failed!" : "Salvarea a eşuat!",
    "Last modified: {date}" : "Modificat ultima dată: {date}",
    "Note has unsaved changes" : "Notiţa are schimbări nesalvate",
    "Subcategory" : "Subcategorie",
    "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"],
    "_%n character_::_%n characters_" : ["%n caracter","%n caractere","%n de caractere"],
    "Write down your thoughts without any distractions." : "Scrie-ţi gândurile fără orice altă distracţie.",
    "Use Markdown markups to style your text." : "Foloseşte limbajul Markdown pentru a-ţi stiliza textul.",
    "Organize your notes in categories." : "Organizează-ţi notoţele pe categorii.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalează alicaţia pentru telefonul tău mobil pentru a-ţi accesa notiţele de oriunde.",
    "Android app" : "Aplicație Android",
    "iOS app" : "Aplicație iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Începe a scrie o notiţă prin a apăsa pe \"{newnote}” în navigaţia aplicaţiei.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Poţi creea subcategorii prin folosirea simbolului \"/\" pentru a delimita categoria principală de subcategorie, ex: “{parent}/{sub}”.",
    "Note not found." : "Notița nu a fost găsită.",
    "Note is locked." : "Notiţa este blocată.",
    "Insufficient storage." : "Spaţiu de stocare insuficient.",
    "See JavaScript console and server log for details." : "Pentru mai multe detalii verificaţi consola JavaScript şi fişierele log.",
    "Updating settings has failed." : "Actualizarea setărilor a eşuat.",
    "Fetching notes for dashboard has failed." : "Preluarea notiţelor pentru ecranul principal a eşuat.",
    "Fetching notes has failed." : "Preluarea notiţelor a eşuat.",
    "Fetching note {id} has failed." : "Preluarea notiţei {id} a eşuat.",
    "Refreshing note {id} has failed." : "Actualizarea notiţei{id} a eşuat.",
    "Renaming note {id} has failed." : "Redenumirea notiţei {id} a eşuat.",
    "Creating new note has failed." : "Creearea unei notiţe noi a eşuat.",
    "Saving note {id} has failed." : "Salvarea notiţei {id} a eşuat. ",
    "Updating title for note {id} has failed." : "Actualizarea titlului pentru notiţa {id} a eşuat.",
    "Undo delete has failed for note {title}." : "Anularea ştergerii notiţei {title} a eşuat.",
    "Deleting note {id} has failed." : "Ştergerea notiţei {id} a eşuat.",
    "Toggling favorite for note {id} has failed." : "Adăugarea la favorite a notiţei {id} a eşuat.",
    "Updating the note's category has failed. Is the target directory writable?" : "Actualizarea categoriei notiţei a eşuat. Există permisiunea de a scrie în dosarul ţintă?",
    "Updating the category for note {id} has failed." : "Actualizarea categoriei pentru notiţa {id} a eşuat.",
    "Development Mode" : "Mod dezvoltator",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Se pare că aplicaţia de luat notiţe a fost instalată dintr-o sursă destinată dezvoltatorilor. Vă rugăm să instalaţi aplicaţia oficială de pe <a href=\"%1$s\">Magazinul Play</a>. Dacă doriţi să contruiţi aplicaţia Notes, vă rugăm să urmaţi <a href=\"%2$s\">instrucţiunile pentru dezvoltatori</a>."
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
