OC.L10N.register(
    "notes",
    {
    "Notes" : "筆記",
    "Reading notes from filesystem has failed." : "從檔案系統讀取筆記失敗。",
    "Error" : "錯誤",
    "New note" : "新筆記",
    "Distraction-free notes and writing" : "無干擾的筆記和寫作",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "筆記應用程式是用於 [Nextcloud]（https://www.nextcloud.com/）的筆記應用程式。其提供了更好的組織分類，並使用［Markdown］（https://zh.wikipedia.org/wiki/Markdown）語法來支援格式化。筆記是以檔案的形式儲存在您的 Nextcloud 中，這樣您就可以使用各種 Nextcloud 客戶端檢視並編輯它們。此外，也有獨立的 [REST API]（https://github.com/nextcloud/notes/blob/master/docs/api/README.md）可輕鬆地整合至第三方的應用程式（目前有供 [Android]（https://github.com/stefan-niedermann/nextcloud-notes）、[iOS]（https://github.com/owncloud/notes-iOS-App）與 [終端機]（https://git。danielmoch。com/nncli/about）使用的應用程式，可讓您方便存取您的 Nextcloud 筆記）。還有將筆記加入收藏的功能。",
    "Please see Nextcloud server log for details." : "請檢視 Nextcloud 伺服器記錄以取得進一步資訊。",
    "Deleted {title}" : "已刪除 {title}",
    "Undo Delete" : "還原刪除",
    "Note recovered" : "筆記已復原",
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未儲存內容。離開頁面會有遺失資料風險。",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["已刪除 {number} 個筆記"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["已回復 {number} 個筆記"],
    "Notes settings" : "Notes 設定",
    "Folder to store your notes" : "儲存筆記的資料夾",
    "Root directory" : "根目錄",
    "File extension for new notes" : "新筆記的副檔名",
    "Display mode for notes" : "筆記顯示模式",
    "User defined" : "使用者定義",
    "Open in edit mode" : "以編輯模式開啟",
    "Open in preview mode" : "以預覽模式開啟",
    "No notes yet" : "尚未有筆記",
    "Upload image" : "上傳圖像",
    "Insert image" : "插入圖像",
    "Select an image" : "選擇圖像",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "您不能選擇筆記資料夾之外的圖像。 您的筆記資料夾是：{folder}",
    "Wrong image" : "錯誤的圖像",
    "The file was not uploaded. Check your server logs." : "檔案未上傳。請檢查您的伺服器紀錄檔。",
    "All notes" : "全部筆記",
    "Categories" : "分類",
    "Loading …" : "正在載入……",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "This week" : "本星期",
    "Last week" : "上星期",
    "This month" : "本月",
    "Last month" : "上月",
    "Rename" : "重新命名",
    "Note's title" : "筆記標題",
    "Delete note" : "刪除筆記",
    "Remove from favorites" : "從最愛中移除",
    "Add to favorites" : "加到我的最愛",
    "Error during preparing note for deletion." : "準備刪除筆記時出錯。",
    "The note has been changed in another session. Please choose which version should be saved." : "該筆記在另一節中已更改。請選擇應保存的版本。",
    "Use version from server" : "使用伺服器版本",
    "Use current version" : "使用目前版本",
    "Empty note" : "無內容",
    "Write …" : "編寫 ...",
    "Details" : "詳細資料",
    "CTRL + /" : "CTRL + /",
    "Edit" : "編輯",
    "Preview" : "預覽",
    "Exit full screen" : "退出全螢幕",
    "Full screen" : "全螢幕",
    "Note is read-only. You cannot change it." : "筆記是唯讀的。您無法更改。",
    "Save failed. Click to retry." : "保存失敗。點擊重試。",
    "Update conflict. Click for resolving manually." : "更新有衝突。 單擊以人手解決。",
    "Error from Nextcloud server: {msg}" : "來自 Nextcloud 伺服器的錯誤通知：{msg}",
    "Set category" : "設置分類",
    "Category" : "分類",
    "Uncategorized" : "未分類",
    "Click here to save manually" : "單擊此處人手保存",
    "Saving failed!" : "保存失敗！",
    "Last modified: {date}" : "上次修改日期：{date}",
    "Note has unsaved changes" : "有未保存內容",
    "Subcategory" : "子分類",
    "_%n word_::_%n words_" : ["%n 個字"],
    "_%n character_::_%n characters_" : ["%n 個字元"],
    "Write down your thoughts without any distractions." : "專心記下你的想法。",
    "Use Markdown markups to style your text." : "使用 Markdown 標記來設定您的文字樣式。",
    "Organize your notes in categories." : "以不同分類組織筆記。",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "在您的手提電話上安裝應用程式以便隨時隨地存取您的筆記。",
    "Android app" : "Android 應用程式",
    "iOS app" : "iOS 應用程式",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "在導覽列點選「{newnote}」以開始編寫筆記。",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "您可以使用 “/” 作為下層分類與上層分類間的分隔符號，例如：“{parent}/{sub}”。",
    "Note not found." : "找不到筆記。",
    "Note is locked." : "筆記已上鎖。",
    "Insufficient storage." : "儲存空間不足。",
    "See JavaScript console and server log for details." : "請檢視 JavaScript 主控台與伺服器紀錄檔以取得詳細資訊。",
    "Updating settings has failed." : "更新設定失敗。",
    "Fetching notes for dashboard has failed." : "為儀表板擷取筆記失敗。",
    "Fetching notes has failed." : "筆記擷取失敗。",
    "Fetching note {id} has failed." : "筆記 {id} 擷取失敗。",
    "Refreshing note {id} has failed." : "筆記 {id} 更新失敗。",
    "Renaming note {id} has failed." : "筆記 {id} 重新命名失敗。",
    "Creating new note has failed." : "創建新筆記失敗。",
    "Saving note {id} has failed." : "筆記 {id} 儲存失敗。",
    "Updating title for note {id} has failed." : "筆記 {id} 標題更新失敗。",
    "Undo delete has failed for note {title}." : "還原已刪除筆記 {title} 失敗。",
    "Deleting note {id} has failed." : "刪除筆記 {id} 失敗。",
    "Toggling favorite for note {id} has failed." : "增/減筆記 {id} 到最愛失敗。",
    "Updating the note's category has failed. Is the target directory writable?" : "更新筆記的分類失敗。檢查目的地目錄屬性是否為可寫入？",
    "Updating the category for note {id} has failed." : "更新筆記 {id} 的分類失敗。",
    "Development Mode" : "研發模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "看來筆記應用程式是從開發中的原始碼安裝的。請從官方的 <a href=\"%1$s\">Nextcloud App Store</a> 安裝。如果您想要自行建構筆記應用程式，請遵循<a href=\"%2$s\">開發者說明</a>進行操作。"
},
"nplurals=1; plural=0;");
