OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Reading notes from filesystem has failed." : "Ha fallado la lectura de las notas desde el sistema de archivos.",
    "Error" : "Error",
    "New note" : "Nueva nota",
    "Distraction-free notes and writing" : "Escritura de notas sin distracciones",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "La app de Notas es una aplicación de escritura de notas sin distracciones para [Nextcloud](https://www.nextcloud.com/). Ofrece categorías para mejorar la organización y soporta el formato mediante [Markdown](https://en.wikipedia.org/wiki/Markdown). Las notas se guardan como archivos en tu Nextcloud, por lo que puedes verlas y editarlas con cada cliente de Nextcloud. Además, una [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) separada permite una integración sencilla con apps de terceras partes (actualmente hay apps de notas para [Android](https://github.com/stefan-niedermann/nextcloud-notes) y [iOS](https://github.com/owncloud/notes-iOS-App) y la [consola](https://git.danielmoch.com/nncli/about) que permiten un acceso cómodo a tus notas de Nextcloud). Otras características incluyen el marcar notas como favoritas.",
    "Please see Nextcloud server log for details." : "Por favor, revisa el registro del servidor de Nextcloud para ver los detalles.",
    "Deleted {title}" : "Borrado {title}",
    "Undo Delete" : "Deshacer Borrado",
    "Note recovered" : "Nota recuperada",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin guardar. ¡Abandonar la página descartará los cambios!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Borrada {number} nota","Borradas {number} notas","Borradas {number} notas"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Recuperada {number} nota","Recuperadas {number} notas","Recuperadas {number} notas"],
    "Notes settings" : "Configuración de Notes",
    "Folder to store your notes" : "Carpeta para almacenar tus notas",
    "Root directory" : "Directorio raíz",
    "File extension for new notes" : "Extensión de archivo para notas nuevas",
    "Display mode for notes" : "Modo de visualización para notas",
    "User defined" : "Definido por el usuario",
    "Open in edit mode" : "Abrir en modo edición",
    "Open in preview mode" : "Abrir en modo de vista previa",
    "No notes yet" : "Aún no hay notas",
    "Upload image" : "Subir imagen",
    "Insert image" : "Insertar imagen",
    "Select an image" : "Selecciona una imagen",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "No puedes seleccionar imágenes fuera de tu carpeta de notas. Tu carpeta de notas es: {folder}",
    "Wrong image" : "Imagen errónea",
    "The file was not uploaded. Check your server logs." : "El archivo no se ha subido. Comprueba los registros de tu servidor.",
    "All notes" : "Todas las notas",
    "Categories" : "Categorías",
    "Loading …" : "Cargando …",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "This week" : "Esta semana",
    "Last week" : "La semana pasada",
    "This month" : "Este mes",
    "Last month" : "El mes pasado",
    "Rename" : "Renombrar",
    "Note's title" : "Título de la nota",
    "Delete note" : "Eliminar nota",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "Error during preparing note for deletion." : "Error al preparar nota para borrado.",
    "The note has been changed in another session. Please choose which version should be saved." : "La nota ha sido cambiada en otra sesión. Por favor, elija cuál debe ser guardada.",
    "Use version from server" : "Usar la versión del servidor",
    "Use current version" : "Usar esta versión",
    "Empty note" : "Nota vacía",
    "Write …" : "Escribir",
    "Details" : "Detalles",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Preview" : "Vista previa",
    "Exit full screen" : "Salir de pantalla completa",
    "Full screen" : "Pantalla completa",
    "Note is read-only. You cannot change it." : "La nota es de sólo lectura. No la puede cambiar.",
    "Save failed. Click to retry." : "Fallo al guardar. Presiona para reintentarlo.",
    "Update conflict. Click for resolving manually." : "Conflicto al actualizar. Elija manualmente para resolver el problema.",
    "Error from Nextcloud server: {msg}" : "Error desde el servidor Nextcloudr: {msg}",
    "Category" : "Categorías",
    "Uncategorized" : "Sin categoría",
    "Set category" : "Escoge categoría",
    "Click here to save manually" : "Pulsa aquí para guardar manualmente",
    "Saving failed!" : "¡Fallo al guardar!",
    "Last modified: {date}" : "Modificado por última vez: {date}",
    "Note has unsaved changes" : "La nota tiene cambios sin guardar",
    "Subcategory" : "Subcategoría",
    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
    "_%n character_::_%n characters_" : ["%n carácter","%n caracteres","%n caracteres"],
    "Write down your thoughts without any distractions." : "Escribe tus pensamientos sin distracciones.",
    "Use Markdown markups to style your text." : "Utilice etiquetado Markdown para dar estilo a su texto.",
    "Organize your notes in categories." : "Organice sus notas en categorías.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instala la app en tu teléfono móvil para acceder a tus notas desde cualquier lugar.",
    "Android app" : "Aplicación de Android",
    "iOS app" : "Aplicación de iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comience a escribir una nota haciendo clic sobre “{newnote}” en la navegación de la App.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podrá crear subcategorías usando \"/\" como separador entre la categoría principal y la subcategoría, como, por ejemplo “{parent}/{sub}\"",
    "Note not found." : "Nota no encontrada.",
    "Note is locked." : "La nota está bloqueada.",
    "Insufficient storage." : "Almacenamiento insuficiente.",
    "See JavaScript console and server log for details." : "Revise la consola JavaScript y el registro del servidor para ver los detalles.",
    "Updating settings has failed." : "Fallo al guardar la configuración modificada.",
    "Fetching notes for dashboard has failed." : "Fallo al recuperar notas desde el  tablero.",
    "Fetching notes has failed." : "Fallo al recuperar las notas.",
    "Fetching note {id} has failed." : "Fallo al recuperar la nota {id}",
    "Refreshing note {id} has failed." : "Fallo al actualizar la nota {id}",
    "Renaming note {id} has failed." : "Fallo al renombrar la nota {id} .",
    "Creating new note has failed." : "Fallo al crear una nueva nota.",
    "Saving note {id} has failed." : "Fallo al guardar la nota {id}.",
    "Updating title for note {id} has failed." : "Fallo al actualizar el título de la nota {id}",
    "Undo delete has failed for note {title}." : "Ha fallado la operación de Deshacer el borrado para la nota {title}.",
    "Deleting note {id} has failed." : "El borrado de la nota {id} ha fallado.",
    "Toggling favorite for note {id} has failed." : "Fallo al marcar la nota {id} como favorita",
    "Updating the note's category has failed. Is the target directory writable?" : "Fallo al actualizar la categoría de la nota. ¿El directorio destino es escribible?",
    "Updating the category for note {id} has failed." : "Fallo al actualizar la categoría de la nota {id}",
    "Development Mode" : "Modo de Desarrollo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que la aplicación de notas ha sido instalada desde una fuente de desarrollo. Por favor instálela desde la <a href=\"%1$s\">AppStore de Nextcloud</a> oficial. Si quieres hacer la aplicación de Notas por ti mismo, por favor sigue las <a href=\"%2$s\">instrucciones para desarrolladores</a>."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
