OC.L10N.register(
    "notes",
    {
    "Error" : "ýalňyşlyk",
    "Today" : "Şu gün",
    "Yesterday" : "Düýn",
    "This week" : "Bu hepdede",
    "Rename" : "Adyny üýtgetmek",
    "Add to favorites" : "Saýlananlara goşuň",
    "Details" : "Jikme-jiklikler",
    "Edit" : "Redaktirläň"
},
"nplurals=2; plural=(n != 1);");
