OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "Reading notes from filesystem has failed." : "Läsa anteckningar från filsystemet misslyckades.",
    "Error" : "Fel",
    "New note" : "Ny anteckning",
    "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
    "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
    "Deleted {title}" : "Raderad {title}",
    "Undo Delete" : "Ångra radering",
    "Note recovered" : "Anteckning återskapad",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Tog bort {number} anteckning","Tog bort {number} anteckningar"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Återskapade {number} anteckning","Återskapade {number} anteckningar"],
    "Folder to store your notes" : "Mapp för att spara dina anteckningar",
    "File extension for new notes" : "Filtillägg för nya anteckningar",
    "Display mode for notes" : "Visningsläge för anteckningar",
    "Open in edit mode" : "Öppna i redigeringsläge",
    "Open in preview mode" : "Öppna i granskningsläge",
    "No notes yet" : "Inga anteckningar än",
    "Insert image" : "Infoga bild",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "Loading …" : "Läser in ...",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Rename" : "Byt namn",
    "Note's title" : "Anteckningens titel",
    "Delete note" : "Ta bort anteckning",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
    "The note has been changed in another session. Please choose which version should be saved." : "Anteckningen har modifierats i en annan session. Vänligen välj vilken version som skall sparas.",
    "Use version from server" : "Använd version från servern",
    "Use current version" : "Använd nuvarande version",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv ...",
    "Details" : "Detaljer",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Redigera",
    "Preview" : "Förhandsvisa",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Note is read-only. You cannot change it." : "Anteckningen är skrivskyddad. Du kan inte ändra den.",
    "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
    "Update conflict. Click for resolving manually." : "Uppdateringskonflikt. Klicka för att lösa upp manuellt.",
    "Error from Nextcloud server: {msg}" : "Fel från Nextcloud server: {msg}",
    "Set category" : "Ange kategori",
    "Category" : "Kategori",
    "Uncategorized" : "Okategoriserad",
    "Click here to save manually" : "Klicka här för att spara manuellt.",
    "Saving failed!" : "Misslyckades att spara!",
    "Last modified: {date}" : "Senast ändrad: {date}",
    "Note has unsaved changes" : "Note har osparade ändringar",
    "Subcategory" : "Underkategori",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "_%n character_::_%n characters_" : ["%n tecken","%n tecken"],
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
    "Note not found." : "Anteckningen hittades inte.",
    "Note is locked." : "Anteckningen är låst.",
    "Insufficient storage." : "Otillräckligt utrymme.",
    "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
    "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
    "Fetching notes for dashboard has failed." : "Hämtning av anteckningar för dashboarden misslyckades",
    "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
    "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
    "Refreshing note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
    "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
    "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
    "Saving note {id} has failed." : "Spara anteckning {id} misslyckades.",
    "Updating title for note {id} has failed." : "Uppdatering av titel för anteckning {id} misslyckades.",
    "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
    "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
    "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
},
"nplurals=2; plural=(n != 1);");
