OC.L10N.register(
    "notes",
    {
    "Notes" : "Notities",
    "Reading notes from filesystem has failed." : "Het ophalen van notities van het bestandssysteem is mislukt.",
    "Error" : "Fout",
    "New note" : "Nieuwe notitie",
    "Distraction-free notes and writing" : "Afleidingsvrije notities en schrijven",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "De Notities-app is een simpele kladblok app voor [Nextcloud](https://www.nextcloud.com/). Het ondersteunt formatteren met [Markdown] (https://en.wikipedia.org/wiki/Markdown). Notities worden als bestanden in je Nextcloud opgeslagen, zodat je ze met elke Nextcloud-client kunt bekijken en bewerken. Bovendien zorgt een afzonderlijke [REST API] (https://github.com/nextcloud/notes/blob/master/docs/api/README.md) voor een eenvoudige integratie met apps van derden (momenteel zijn er notitie-apps voor [Android] (https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) en de [console](https://git.danielmoch.com/nncli/about) waarmee je eenvoudig toegang krijgt tot je Nextcloud notites). Meer functies zijn o.a. het als favoriet markeren van je notities.",
    "Please see Nextcloud server log for details." : "Bekijk het Nextcloud-serverlogboek voor details.",
    "Deleted {title}" : "{title} verwijderd",
    "Undo Delete" : "Verwijderen ongedaan maken",
    "Note recovered" : "Notitie hersteld",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Er zijn niet-opgeslagen notities. Als je de pagina verlaat gaan je wijzigingen verloren!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Verwijderde {number} notitie","{number} notities verwijderd"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Herstelde {number} notitie","{number} notities hersteld"],
    "Notes settings" : "Notities instellingen",
    "Folder to store your notes" : "Map om je notities in op te slaan",
    "Root directory" : "Root directory",
    "File extension for new notes" : "Bestandsextensie voor nieuwe notities",
    "Display mode for notes" : "Weergavemodus voor notities",
    "User defined" : "Door gebruiker ingesteld",
    "Open in edit mode" : "Open in bewerkingsmodus",
    "Open in preview mode" : "Open in voorbeeldmodus",
    "No notes yet" : "Nog geen notities aanwezig",
    "Upload image" : "Upload afbeelding",
    "Insert image" : "Invoegen afbeelding",
    "Select an image" : "Selecteer een afbeelding",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "U kan geen beelden kiezen buiten uw notities map. Uw notities map is {folder}",
    "Wrong image" : "Verkeerde afbeelding",
    "The file was not uploaded. Check your server logs." : "Het bestand is niet geupload. Bekijk uw Server-logboeken",
    "All notes" : "Alle notities",
    "Categories" : "Categorieën",
    "Loading …" : "Laden ...",
    "Today" : "Vandaag",
    "Yesterday" : "Gisteren",
    "This week" : "Deze week",
    "Last week" : "Vorige week",
    "This month" : "Deze maand",
    "Last month" : "Vorige maand",
    "Rename" : "Hernoemen",
    "Note's title" : "Notitietitel",
    "Delete note" : "Verwijder notitie",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Toevoegen aan favorieten",
    "Error during preparing note for deletion." : "Fout bij voorbereiden van verwijdering van notitie",
    "The note has been changed in another session. Please choose which version should be saved." : "De notitie is aangepast in een andere sessie. Kies welke versie opgeslagen moet worden.",
    "Use version from server" : "Gebruik de versie van de server",
    "Use current version" : "Gebruik de huidige versie",
    "Empty note" : "Lege notitie",
    "Write …" : "Schrijf ...",
    "Details" : "Details",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Bewerken",
    "Preview" : "Voorbeeld",
    "Exit full screen" : "Verlaat volledig scherm",
    "Full screen" : "Volledig scherm",
    "Note is read-only. You cannot change it." : "Notitie is in alleen-lezen modus. Je kunt die niet wijzigen.",
    "Save failed. Click to retry." : "Opslaan mislukt. Klik om opnieuw te proberen.",
    "Update conflict. Click for resolving manually." : "Bijwerkconflict. Klik om het handmatig op te lossen.",
    "Error from Nextcloud server: {msg}" : "Fout van Nextcloud-server: {msg}",
    "Set category" : "Bepaal categorie",
    "Category" : "Categorie",
    "Uncategorized" : "Niet gecategoriseerd ",
    "Click here to save manually" : "Klik hier om handmatig op te slaan",
    "Saving failed!" : "Opslaan mislukt!",
    "Last modified: {date}" : "Laatst gewijzigd: {date}",
    "Note has unsaved changes" : "De notitie heeft niet-opgeslagen wijzigingen.",
    "Subcategory" : "Subcategorie",
    "_%n word_::_%n words_" : ["%n woord","%n woorden"],
    "_%n character_::_%n characters_" : ["%n teken","%n tekens"],
    "Write down your thoughts without any distractions." : "Schrijf je gedachten op zonder afleiding.",
    "Use Markdown markups to style your text." : "Gebruik Markdown markeringen om je tekst op te maken.",
    "Organize your notes in categories." : "Organiseer je notities in categorieën. ",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installeer de app op je mobiel om overal toegang tot je notities te krijgen.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Start een nieuwe notitie door op \"{newnote}\" te klikken in de app navigatie.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Je kunt sub-categorieën maken door “/” te gebruiken als scheidingsteken tussen hoofdcategorie en sub-categorie, bijv. “{parent}/{sub}”.",
    "Note not found." : "Notitie niet gevonden.",
    "Note is locked." : "Notitie is geblokkeerd.",
    "Insufficient storage." : "Onvoldoende opslagruimte",
    "See JavaScript console and server log for details." : "Bekijk JavaScript-console en server-log voor details.",
    "Updating settings has failed." : "Update van instellingen mislukt.",
    "Fetching notes for dashboard has failed." : "Ophalen van notities voor dashboard mislukt.",
    "Fetching notes has failed." : "Notities ophalen mislukt.",
    "Fetching note {id} has failed." : "Notitie {id} ophalen mislukt.",
    "Refreshing note {id} has failed." : "Het vernieuwen van notitie {id} is mislukt.",
    "Renaming note {id} has failed." : "Hernoemen notitie {id} mislukt.",
    "Creating new note has failed." : "Notitie aanmaken mislukt.",
    "Saving note {id} has failed." : "Opslaan notitie {id} mislukt.",
    "Updating title for note {id} has failed." : "Het updaten van de titel voor notitie {id} is mislukt.",
    "Undo delete has failed for note {title}." : "Verwijderen ongedaan maken is mislukt voor notitie {title}.",
    "Deleting note {id} has failed." : "Notitie {id} verwijderen mislukt.",
    "Toggling favorite for note {id} has failed." : "Favoriet bijwerken voor notitie {id} mislukt.",
    "Updating the note's category has failed. Is the target directory writable?" : "Bijwerken van de notitiecategorie mislukt. Is de doelmap beschrijfbaar?",
    "Updating the category for note {id} has failed." : "Categorie bijwerken voor notitie {id} mislukt.",
    "Development Mode" : "Ontwikkelmodus",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Het lijkt erop dat de Notities-app werd geïnstalleerd vanuit een ontwikkelbron. Installeer de app alsjeblieft vanuit de officiële <a href=\"%1$s\">Nextcloud App Store</a>. Als je de Notities-app zelf wilt opbouwen, volg dan de  <a href=\"%2$s\">ontwikkelaarsinstructies</a>."
},
"nplurals=2; plural=(n != 1);");
