OC.L10N.register(
    "notes",
    {
    "Notes" : "Заметки",
    "Reading notes from filesystem has failed." : "Чтение заметок из файловой системы не удалось",
    "Error" : "Ошибка",
    "New note" : "Новая заметка",
    "Distraction-free notes and writing" : "Простые заметки и записки",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Приложение «Заметки» - это приложение [Nextcloud](https://www.nextcloud.com/) для быстрого создания заметок по текущим делам. Приложение позволяет объединять заметки в категории и поддерживает форматирование с использованием синтаксиса [Markdown](https://en.wikipedia.org/wiki/Markdown). Поскольку каждая заметка хранится в облаке Nextcloud в отдельном файле, Вы можете просматривать и править заметки, используя любое клиентское приложение Nextcloud. Независимый [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) обеспечивает возможность его легкой интеграции в сторонние приложения: в настоящее время приложение «Заметки» создано для [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) и [командной строки](https://git.danielmoch.com/nncli/about) с удобным доступом к заметкам, размещённым в облаке Nextcloud. Приятным дополнением к перечисленному является возможность помещать отдельные заметки в избранное.",
    "Please see Nextcloud server log for details." : "Для получения подробной информации, пожалуйста, обратитесь к журналам сервера Nextcloud.",
    "Deleted {title}" : "Заметка {title} удалена",
    "Undo Delete" : "Отменить удаление",
    "Note recovered" : "Заметка восстановлена",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Есть несохраненные заметки. Если покинуть страницу, все изменения будут утеряны.",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Удалена [number] заметка","Удалено [number] заметки","Удалено [number] заметок","Удалено [number] заметок"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Восстановлена [number] заметка","Восстановлено [number] заметки","Восстановлено [number] заметок","Восстановлено [number] заметок"],
    "Folder to store your notes" : "Папка для хранения заметок",
    "Root directory" : "Корневой каталог",
    "File extension for new notes" : "Расширения файлов новых заметок",
    "Display mode for notes" : "Режим отображения для заметок",
    "User defined" : "Определено пользователем",
    "Open in edit mode" : "Открыть в режиме редактирования",
    "Open in preview mode" : "Открыть в режиме просмотра",
    "No notes yet" : "Нет ни одной заметки",
    "Upload image" : "Загрузить изображение",
    "Insert image" : "Вставить изображение",
    "Select an image" : "Выберите изображение",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Вы не можете выбрать изображения вне папки заметок. Ваша папка заметок: {папка}",
    "Wrong image" : "Неверное изображение",
    "The file was not uploaded. Check your server logs." : "Файл не был загружен. Проверьте журналы вашего сервера.",
    "All notes" : "Все заметки",
    "Categories" : "Категории",
    "Loading …" : "Загрузка ...",
    "Today" : "Сегодня",
    "Yesterday" : "Вчера",
    "This week" : "Эта неделя",
    "Last week" : "За последнюю неделю",
    "This month" : "Этот месяц",
    "Last month" : "За последний месяц",
    "Rename" : "Переименовать",
    "Note's title" : "Заголовок заметки",
    "Delete note" : "Удалить заметку",
    "Remove from favorites" : "Убрать из избранного",
    "Add to favorites" : "Добавить в избранное",
    "Error during preparing note for deletion." : "Не удалось подготовить заметку к удалению,",
    "The note has been changed in another session. Please choose which version should be saved." : "Данная заметка была изменена в другой сессии. Пожалуйста, выберите, какую версию сохранить.",
    "Use version from server" : "Использовать версию с сервера",
    "Use current version" : "Использовать текущую версию",
    "Empty note" : "Пустая заметка",
    "Write …" : "Запись…",
    "Details" : "Подробнее",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Править",
    "Preview" : "Предпросмотр",
    "Exit full screen" : "Выйти из полноэкранного режима",
    "Full screen" : "Во весь экран",
    "Note is read-only. You cannot change it." : "Заметка только для чтения. Вы не можете изменить её.",
    "Save failed. Click to retry." : "Сохранение не удалось. Нажмите для повтора.",
    "Update conflict. Click for resolving manually." : "Конфликт обновления. Щелкните для разрешения вручную.",
    "Error from Nextcloud server: {msg}" : "Ошибка сервера Nextcloud: {msg}",
    "Set category" : "Задать категорию",
    "Category" : "Категория",
    "Uncategorized" : "Без категории",
    "Click here to save manually" : "Нажмите для принудительного сохранения",
    "Saving failed!" : "Не удалось сохранить",
    "Last modified: {date}" : "Последнее изменение: {date}",
    "Note has unsaved changes" : "Заметка содержит несохраненные изменения",
    "Subcategory" : "Подкатегория",
    "_%n word_::_%n words_" : ["%n слово","%n слова","%n слов","%n слов"],
    "_%n character_::_%n characters_" : ["%n символ","%n символа","%n символов","%n символов"],
    "Write down your thoughts without any distractions." : "Записывайте свои мысли, ни на что не отвлекаясь.",
    "Use Markdown markups to style your text." : "Поддержка языка разметки Markdown для оформления текста;",
    "Organize your notes in categories." : "Поддержка категорий;",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Для доступа к заметкам с телефона установите мобильное приложение.",
    "Android app" : "Приложение Android",
    "iOS app" : "Приложение iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Чтобы создать заметку, нажмите «{newnote}» в панели навигации.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Для создания вложенных категорий используйте разделитель «/», например: «{parent}/{sub}».",
    "Note not found." : "Заметка не найдена",
    "Note is locked." : "Заметка заблокирована",
    "Insufficient storage." : "Ндостаточно места",
    "See JavaScript console and server log for details." : "Подробные сведения приведены в консоли JavaScript и файле журнала сервера.",
    "Updating settings has failed." : "Не удалось сохранить изменения.",
    "Fetching notes for dashboard has failed." : "Загрузка заметок на панель не удалось.",
    "Fetching notes has failed." : "Не удалось получить заметки.",
    "Fetching note {id} has failed." : "Не удалось получить заметку {id}.",
    "Refreshing note {id} has failed." : "Обновление заметки {id} не удалось",
    "Renaming note {id} has failed." : "Не удалось переименовать заметку {id}.",
    "Creating new note has failed." : "Не удалось создать заметку.",
    "Saving note {id} has failed." : "Сохранение заметки {id} не удалось",
    "Updating title for note {id} has failed." : "Обновление заголовка для заметки {id} не удалось",
    "Undo delete has failed for note {title}." : "Не удалось отменить удаление заметки {title}.",
    "Deleting note {id} has failed." : "Не удалось удалить заметку {id}.",
    "Toggling favorite for note {id} has failed." : "Не удалось установить отметку «избранное» для заметки {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Ошибка обновления категории заметки. Разрешена ли запись в целевую директорию?",
    "Updating the category for note {id} has failed." : "Не удалось обновить категорию для заметки {id}.",
    "Development Mode" : "Режим разработки",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Вероятно, это приложение было установлено из источника, предназначенного для разработчиков. Настоятельно рекомендуется переустановить его из официального <a href=\"%1$s\">каталога приложений Nextcloud</a>. Инструкции по самостоятельной сборке приложения приведены в  <a href=\"%2$s\">руководстве для разработчиков</a>."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
