OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Reading notes from filesystem has failed." : "S'ha produït un error en llegir les notes del sistema de fitxers.",
    "Error" : "Error",
    "New note" : "Nota nova",
    "Distraction-free notes and writing" : "Preneu notes i escriviu sense distraccions",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "L'aplicació Notes és una aplicació de notes sense distraccions per al [Nextcloud](https://www.nextcloud.com/). Proporciona categories per a millorar l'organització i admet el format mitjançant la sintaxi [Markdown](https://en.wikipedia.org/wiki/Markdown). Les notes es desen com a fitxers al Nextcloud, de manera que podeu visualitzar-les i editar-les amb qualsevol client del Nextcloud. A més, una [API REST](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) independent permet una integració fàcil en aplicacions de tercers (actualment, hi ha aplicacions de notes per a l'[Android](https://github.com/stefan-niedermann/nextcloud-notes), l'[iOS](https://github.com/owncloud/notes-iOS-App) i la [consola](https://git.danielmoch.com/nncli/about) que permeten accedir còmodament a les vostres notes del Nextcloud). Altres característiques inclouen marcar les notes com a preferides.",
    "Please see Nextcloud server log for details." : "Consulteu el registre del servidor del Nextcloud per a veure més detalls.",
    "Deleted {title}" : "S'ha suprimit {title}",
    "Undo Delete" : "Desfés la supressió",
    "Note recovered" : "S'ha recuperat la nota",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hi ha notes sense desar. Si sortiu de la pàgina, es perdran tots els canvis!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["S'ha suprimit {number} nota","S'han suprimit {number} notes"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["S'ha recuperat {number} nota","S'han recuperat {number} notes"],
    "Folder to store your notes" : "Carpeta on es desen les notes",
    "Root directory" : "Carpeta arrel",
    "File extension for new notes" : "Extensió de fitxer per a les notes noves",
    "Display mode for notes" : "Mode de visualització de les notes",
    "User defined" : "Definida per l'usuari",
    "Open in edit mode" : "Obre en mode d'edició",
    "Open in preview mode" : "Obre en mode de previsualització",
    "No notes yet" : "Encara no hi ha notes",
    "Upload image" : "Puja una imatge",
    "Insert image" : "Insereix una imatge",
    "Select an image" : "Seleccioneu una imatge",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "No podeu seleccionar notes que es trobin fora de la carpeta de notes. La carpeta de notes és: {folder}",
    "Wrong image" : "Imatge incorrecta",
    "The file was not uploaded. Check your server logs." : "No s'ha pujat el fitxer. Consulteu els registres del servidor.",
    "All notes" : "Totes les notes",
    "Categories" : "Categories",
    "Loading …" : "S'està carregant…",
    "Today" : "Avui",
    "Yesterday" : "Ahir",
    "This week" : "Aquesta setmana",
    "Last week" : "La setmana passada",
    "This month" : "Aquest mes",
    "Last month" : "El mes passat",
    "Rename" : "Canvia el nom",
    "Note's title" : "Títol de la nota",
    "Delete note" : "Suprimeix la nota",
    "Remove from favorites" : "Suprimeix de preferits",
    "Add to favorites" : "Afegeix als preferits",
    "Error during preparing note for deletion." : "S'ha produït un error en preparar la nota per la supressió.",
    "The note has been changed in another session. Please choose which version should be saved." : "S'ha modificat la nota en una altra sessió. Trieu quina versió voleu desar.",
    "Use version from server" : "Utilitza la versió del servidor",
    "Use current version" : "Utilitza la versió actual",
    "Empty note" : "Nota en blanc",
    "Write …" : "Escriviu…",
    "Details" : "Detalls",
    "CTRL + /" : "Ctrl + /",
    "Edit" : "Edita",
    "Preview" : "Previsualitza",
    "Exit full screen" : "Surt de la pantalla completa",
    "Full screen" : "Pantalla completa",
    "Note is read-only. You cannot change it." : "La nota és de només lectura. No la podeu modificar.",
    "Save failed. Click to retry." : "S'ha produït un error en desar. Feu clic per a tornar-ho a provar.",
    "Update conflict. Click for resolving manually." : "S'ha produït un conflicte d'actualització. Feu clic per a resoldre'l manualment.",
    "Error from Nextcloud server: {msg}" : "Error del servidor del Nextcloud: {msg}",
    "Set category" : "Defineix la categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Sense categoria",
    "Click here to save manually" : "Feu clic aquí per a desar la nota manualment",
    "Saving failed!" : "S'ha produït un error en desar la nota!",
    "Last modified: {date}" : "Darrera modificació: {date}",
    "Note has unsaved changes" : "La nota té canvis sense desar",
    "Subcategory" : "Subcategoria",
    "_%n word_::_%n words_" : ["%n paraula","%n paraules"],
    "_%n character_::_%n characters_" : ["%n caràcter","%n caràcters"],
    "Write down your thoughts without any distractions." : "Escriviu els vostres pensaments sense distraccions.",
    "Use Markdown markups to style your text." : "Utilitzeu el format Markdown per a donar estil al text.",
    "Organize your notes in categories." : "Organitzeu les vostres notes en categories.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instal·leu l'aplicació en el mòbil per a poder accedir a les vostres notes des de qualsevol lloc.",
    "Android app" : "Aplicació per a l'Android",
    "iOS app" : "Aplicació per a l'iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Per a començar a escriure una nota, feu clic a «{newnote}» a la navegació de l'aplicació.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Podeu crear subcategories utilitzant «/» com a delimitador entre la categoria principal i la subcategoria. Per exemple, «{parent}/{sub}».",
    "Note not found." : "No s'ha trobat la nota.",
    "Note is locked." : "La nota està blocada.",
    "Insufficient storage." : "No hi ha prou espai d'emmagatzematge.",
    "See JavaScript console and server log for details." : "Consulteu la consola de JavaScript i els registres del servidor per a veure més detalls.",
    "Updating settings has failed." : "S'ha produït un error en actualitzar els paràmetres.",
    "Fetching notes for dashboard has failed." : "S'ha produït un error en recuperar les notes del tauler.",
    "Fetching notes has failed." : "S'ha produït un error en recuperar les notes.",
    "Fetching note {id} has failed." : "S'ha produït un error en recuperar la nota {id}.",
    "Refreshing note {id} has failed." : "S'ha produït un error en actualitzar la nota {id}.",
    "Renaming note {id} has failed." : "S'ha produït un error en canviar el nom de la nota {id}.",
    "Creating new note has failed." : "S'ha produït un error en crear una nota nova.",
    "Saving note {id} has failed." : "S'ha produït un error en desar la nota {id}.",
    "Updating title for note {id} has failed." : "S'ha produït un error en actualitzar el títol de la nota {id}.",
    "Undo delete has failed for note {title}." : "S'ha produït un error en desfer la supressió de la nota {title}.",
    "Deleting note {id} has failed." : "S'ha produït un error en suprimir la nota {id}.",
    "Toggling favorite for note {id} has failed." : "S'ha produït un error en canviar l'estat de preferit de la nota {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "S'ha produït un error en actualitzar la categoria de la nota. Teniu permís d'escriptura a la carpeta de destinació?",
    "Updating the category for note {id} has failed." : "S'ha produït un error en actualitzar la categoria de la nota {id}.",
    "Development Mode" : "Mode de desenvolupament",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembla que l'aplicació Notes s'ha instal·lat des d'una font de desenvolupament. Instal·leu-la des de la <a href=\"%1$s\">Botiga d'aplicacions del Nextcloud</a> oficial en el seu lloc. Si voleu compilar l'aplicació Notes pel vostre compte, seguiu les <a href=\"%2$s\"> instruccions per a desenvolupadors</a>."
},
"nplurals=2; plural=(n != 1);");
