OC.L10N.register(
    "notes",
    {
    "Notes" : "Poznámky",
    "Reading notes from filesystem has failed." : "Čítanie poznámok zo súborového systému zlyhalo.",
    "Error" : "Chyba",
    "New note" : "Nová poznámka",
    "Distraction-free notes and writing" : "Písanie a poznámky, čo neodpútavajú pozornosť",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikácia Poznámky pre [Nextcloud](https://www.nextcloud.com/) je bez rozptyľovania. Pre lepšiu organizáciu poskytuje kategórie a podporuje formátovanie pomocou [Markdown](https://en.wikipedia.org/wiki/Markdown). Poznámky sa ukladajú ako súbory vo vašom Nextcloude, takže si ich môžete prezerať a upravovať s každým klientom Nextcloudu. Samostatné [REST API]((https://github.com/nextcloud/notes/blob/master/docs/api/README.md) navyše umožňuje ľahkú integráciu do aplikácií tretích strán (v súčasnosti existujú aplikácie pre poznámky pre [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) a [console](https://git.danielmoch.com/nncli/about), ktoré umožňujú pohodlný prístup do vašich poznámok Nextcloud). Medzi ďalšie vlastnosti patrí označovanie poznámok ako obľúbených položiek.",
    "Please see Nextcloud server log for details." : "Podrobnosti nájdete v protokole servera Nextcloud.",
    "Deleted {title}" : "Zmazané {title}",
    "Undo Delete" : "Zrušiť odstránenie",
    "Note recovered" : "Poznámka bola obnovená",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Máte neuložené poznámky. Opustením stránky stratíte všetky zmeny!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Bola odstránená {number} poznámka","Boli odstránené {number} poznámky","Boli odstránené {number} poznámky","Bolo odstránených {number} poznámok"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Bola obnovená {number} poznámka","Boli obnovené {number} poznámky","Boli obnovené {number} poznámky","Bolo obnovených {number} poznámok"],
    "Notes settings" : "Nastavenia Poznámok",
    "Folder to store your notes" : "Priečinok na ukladanie poznámok",
    "Root directory" : "Koreňový adresár",
    "File extension for new notes" : "Prípona súboru pre nové poznámky",
    "Display mode for notes" : "Režim zobrazovania poznámok",
    "User defined" : "Definované uživateľom",
    "Open in edit mode" : "Otvoriť v režime úprav",
    "Open in preview mode" : "Otvoriť v režime ukážky",
    "No notes yet" : "Zatiaľ nie sú žiadne poznámky",
    "Upload image" : "Nahrať obrázok",
    "Insert image" : "Vložiť obrázok",
    "Select an image" : "Vybrať obrázok",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nemôžete vybrať obrázky mimo priečinka poznámok. Váš priečinok poznámok je: {folder}",
    "Wrong image" : "Chybný obrázok",
    "The file was not uploaded. Check your server logs." : "Súbor nebol nahraný. Skontrolujte záznam o chybách serveru.",
    "All notes" : "Všetky poznámky",
    "Categories" : "Kategórie",
    "Loading …" : "Načítava sa...",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "This week" : "Tento týždeň",
    "Last week" : "Minulý týždeň",
    "This month" : "Tento mesiac",
    "Last month" : "Minulý mesiac",
    "Rename" : "Premenovať",
    "Note's title" : "Nadpis poznámky",
    "Delete note" : "Zmazať poznámku",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "Error during preparing note for deletion." : "Chyba pri príprave poznámky na vymazanie.",
    "The note has been changed in another session. Please choose which version should be saved." : "Poznámka bola zmenená v inej relácii. Prosím vyberte ktorá verzia má byť uložená.",
    "Use version from server" : "Použiť verziu zo servera",
    "Use current version" : "Použiť aktuálnu verziu",
    "Empty note" : "Prázdna poznámka",
    "Write …" : "Písať …",
    "Details" : "Podrobnosti",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Upraviť",
    "Preview" : "Náhľad",
    "Exit full screen" : "Opustiť celú obrazovku",
    "Full screen" : "Na celú obrazovku",
    "Note is read-only. You cannot change it." : "Poznámka je iba na čítanie. Nemôžete ju zmeniť.",
    "Save failed. Click to retry." : "Uloženie zlyhalo. Ťuknutím zopakujete.",
    "Update conflict. Click for resolving manually." : "Konflikt pri aktualizácii. Kliknite pre ručné riešenie problému.",
    "Error from Nextcloud server: {msg}" : "Chyba Nextcloud servera: {msg}",
    "Category" : "Kategória",
    "Uncategorized" : "Nezaradené",
    "Set category" : "Vybrať kategóriu",
    "Click here to save manually" : "Kliknite sem pre automatické uloženie",
    "Saving failed!" : "Ukladanie zlyhalo!",
    "Last modified: {date}" : "Naposledy zmenené: {date}",
    "Note has unsaved changes" : "Poznámka má neuložené zmeny",
    "Subcategory" : "Podkategória",
    "_%n word_::_%n words_" : ["%n slovo","%n slov","%n slov","%n slov"],
    "_%n character_::_%n characters_" : ["%n znak","%n znaky","%n znaky","%n znakov"],
    "Write down your thoughts without any distractions." : "Zapíšte si nápady bez rušivých elementov.",
    "Use Markdown markups to style your text." : "Použite formát Markdown na formátovanie vášho textu.",
    "Organize your notes in categories." : "Organizujte si poznámky do kategórií.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Nainštalujte si aplikáciu pre váš mobil a zoberte si vaše poznámky so sebou kamkoľvek.",
    "Android app" : "Aplikácia pre Android",
    "iOS app" : "Aplikácia pre iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Začnite písať poznámku kliknutím na “{newnote}” v menu aplikácie.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Môžete vytvoriť subkategórie tak, že pridáte oddeľovací znak “/” medzi kategóriu a subkategóriu. Príklad: “{parent}/{sub}”",
    "Note not found." : "Poznámky sa nenašli.",
    "Note is locked." : "Poznámka je zamknutá.",
    "Insufficient storage." : "Nedostatočný úložný priestor.",
    "See JavaScript console and server log for details." : "Podrobnosti nájdete v konzole JavaScriptu a protokole servera.",
    "Updating settings has failed." : "Aktualizácia nastavení zlyhala.",
    "Fetching notes for dashboard has failed." : "Načítanie poznámok pre infopanel zlyhalo.",
    "Fetching notes has failed." : "Získavanie poznámok zlyhalo.",
    "Fetching note {id} has failed." : "Získavanie poznámky {id} zlyhalo.",
    "Refreshing note {id} has failed." : "Obnovenie poznámky {id} zlyhalo.",
    "Renaming note {id} has failed." : "Nepodarilo sa premenovat poznámku {id}",
    "Creating new note has failed." : "Vytvorenie novej poznámky zlyhalo.",
    "Saving note {id} has failed." : "Uloženie poznámky {id} zlyhalo.",
    "Updating title for note {id} has failed." : "Aktualizácia názvu poznámky {id} zlyhala.",
    "Undo delete has failed for note {title}." : "Zrušenie odstránenia zlyhalo pre poznámku {title}.",
    "Deleting note {id} has failed." : "Zmazanie poznámky {id} zlyhalo.",
    "Toggling favorite for note {id} has failed." : "Zaradenie poznámky {id} do obľúbených zlyhalo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualizácia kategórie poznámky zlyhalo. Je možné do cieľového priečinka zapisovať?",
    "Updating the category for note {id} has failed." : "Aktualizácia kategórie pre poznámku {id} zlyhala.",
    "Development Mode" : "Režim pre vývojárov",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Zdá sa, že apka Poznámky bola nainštalovaná zo zdroja pre vývojárov. Nainštalujte ju prosím z oficiálneho <a href=\"%1$s\">Nextcloud katalógu apiek</a>. Ak si chcete zostaviť (skompilovať) aplikáciu Poznámky sami, nasledujte <a href=\"%2$s\">pokyny pre vývojárov</a>."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
