/* workaround for https://github.com/nextcloud/nextcloud-vue/issues/1384 */
body {
	min-height: 100%;
	height: auto;
}

/* App Navigation fixes */
.app-navigation-entry.category-header:not(.app-navigation-entry--opened) .app-navigation-entry__title {
	font-weight: bold;
}

#app-navigation > ul > li.app-navigation-caption.caption-item {
	padding: 0;
	pointer-events: inherit;
}

.app-navigation-entry__utils .action-item {
	visibility: hidden;
}

li.actionsOpen .app-navigation-entry__utils .action-item,
li.app-navigation-entry--deleted .app-navigation-entry__utils .action-item,
li.active .app-navigation-entry__utils .action-item,
li:hover  .app-navigation-entry__utils .action-item,
li:focus  .app-navigation-entry__utils .action-item {
	visibility: visible;
}

@media print {
	#header,
	.app-navigation,
	#note-container .action-buttons,
	#note-container .upload-button {
		display: none !important;
	}

	.content {
		display: block;
		padding: 0;
		color: #000;
	}

	#note-container .note-editor,
	#note-container .note-preview {
		padding: 0 !important;
		font-size: 10pt !important;
	}

	.app-content {
		margin-left: 0 !important;
	}
}
