OC.L10N.register(
    "notes",
    {
    "Notes" : "Oharrak",
    "Reading notes from filesystem has failed." : "Fitxategi-sistemaren ohar-irakurketak huts egin du.",
    "Error" : "Errorea",
    "New note" : "Ohar berria",
    "Distraction-free notes and writing" : "Distrakziorik gabeko oharrak eta idazkiak",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Oharrak aplikazioa distrakziorik gabe oharrak hartzeko [Nextcloud](https://www.nextcloud.com/)-erako aplikazio bat da. Hobeto antolatzeko kategoriak eskaintzen ditu eta [Markdown](https://eu.wikipedia.org/wiki/Markdown) sintaxia erabiliz formatua ematea onartzen du. Oharrak fitxategi bezala gordetzen direnez zure Nextcloudean, edozein Nextcloud bezero erabiliz ikusi eta editatu ditzakezu. Gainera, hirugarrenen aplikazioekin integrazioa errazten duen [REST API](docs/api/README.md) berezi bat ere badago (une honetan, zure Nextcloud oharretara sarbide erraza eskaintzen duten oharrak hartzeko aplikazioak daude [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) eta [kontsolarako](https://git.danielmoch.com/nncli/about)). Ezaugarri gehigarrien artean dago oharrak gogoko bezala markatzeko aukera.",
    "Please see Nextcloud server log for details." : "Ikus Nextcloud zerbitzari-egunkaria xehetasunak eskuratzeko.",
    "Deleted {title}" : "{title} ezabatuta",
    "Undo Delete" : "Desegin ezabatzea",
    "Note recovered" : "Oharra berreskuratuta",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko oharrak daude. Orrialdetik irtetean aldaketa guztiak galduko dira!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{Number} ohar ezabatu dira","{number} ohar ezabatuta"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} ohar berreskuratuta","{number} ohar berreskuratuta"],
    "Notes settings" : "Noten ezarpenak",
    "Folder to store your notes" : "Zure oharrak gordetzeko karpeta",
    "Root directory" : "Erro karpeta",
    "File extension for new notes" : "Ohar berrien fitxategi-luzapena",
    "Display mode for notes" : "Erakusketa modua oharrentzat",
    "User defined" : "Erabiltzaile definitua",
    "Open in edit mode" : "Ireki edizio moduan",
    "Open in preview mode" : "Ireki aurrebista moduan",
    "No notes yet" : "Ez dago oharrik",
    "Upload image" : "Kargatu irudia",
    "Insert image" : "Txertatu irudia",
    "Select an image" : "Hautatu irudi bat",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ezin duzu hautatu irudirik zure ohar karpetatik kanpo. Zure ohar karpeta hau da: {folder}",
    "Wrong image" : "Okerreko irudia",
    "The file was not uploaded. Check your server logs." : "Fitxategia ez da kargatu. Egiaztatu zure zerbitzariaren erregistroak.",
    "All notes" : "Ohar guztiak",
    "Categories" : "Kategoriak",
    "Loading …" : "Kargatzen...",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "This week" : "Aste honetan",
    "Last week" : "Azken astean",
    "This month" : "Hilabete honetan",
    "Last month" : "Azken hilabetean",
    "Rename" : "Berrizendatu",
    "Note's title" : "Oharraren izenburua",
    "Delete note" : "Ezabatu oharra",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add to favorites" : "Gehitu gogokoetan",
    "Error during preparing note for deletion." : "Errorea oharra ezabatzeko prestatzean.",
    "The note has been changed in another session. Please choose which version should be saved." : "Oharra beste saio batean aldatu da. Aukeratu zein bertsio gorde behar den.",
    "Use version from server" : "Erabili zerbitzariaren bertsioa",
    "Use current version" : "Erabili uneko bertsioa",
    "Empty note" : "Ohar hutsa",
    "Write …" : "Idatzi …",
    "Details" : "Xehetasunak",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editatu",
    "Preview" : "Aurrebista",
    "Exit full screen" : "Irten pantaila osotik",
    "Full screen" : "Pantaila osoa",
    "Note is read-only. You cannot change it." : "Oharra irakurtzeko soilik da. Ezin duzu aldatu.",
    "Save failed. Click to retry." : "Huts egin du gordetzean. Egin klik berriro saiatzeko.",
    "Update conflict. Click for resolving manually." : "Eguneraketa gatazka. Egin klik eskuz ebazteko.",
    "Error from Nextcloud server: {msg}" : "Nextcloud zerbitzariaren errorea: {msg}",
    "Set category" : "Ezarri kategoria",
    "Category" : "Kategoria",
    "Uncategorized" : "Sailkatu gabe",
    "Click here to save manually" : "Sakatu hemen eskuz gordetzeko",
    "Saving failed!" : "Gordetzean errorea!",
    "Last modified: {date}" : "Azken aldaketa: {date}",
    "Note has unsaved changes" : "Oharrak gorde gabeko aldaketak ditu",
    "Subcategory" : "Azpikategoria",
    "_%n word_::_%n words_" : ["%n hitz","%n hitz"],
    "_%n character_::_%n characters_" : ["karaktere %n","%n karaktere"],
    "Write down your thoughts without any distractions." : "Idatzi zure ideiak distrakziorik gabe",
    "Use Markdown markups to style your text." : "Erabili Markdown markatzea zure testuari estiloa emateko.",
    "Organize your notes in categories." : "Antolatu zure oharrak kategoriatan.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalatu mugikorrerako aplikazioa zure oharrak edonondik atzitzeko.",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Hasi ohar bat idazten aplikazioaren nabigazioko “{newnote}” aukeran klik eginez.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Azpikategoriak sor ditzakezu “/” banatzaile bezala erabiliz kategoria guraso eta azpikategoriaren artean. Adibidez “{parent}/{sub}”.",
    "Note not found." : "Oharra ez da aurkitu.",
    "Note is locked." : "Oharra blokeatuta dago.",
    "Insufficient storage." : "Ez dago nahikoa biltegi.",
    "See JavaScript console and server log for details." : "Ikusi JavaScript kontsola eta zerbitzariaren egunkariak xehetasunetarako.",
    "Updating settings has failed." : "Ezarpenak eguneratzeak huts egin du.",
    "Fetching notes for dashboard has failed." : "Panelerako oharrak eskuratzeak huts egin du.",
    "Fetching notes has failed." : "Oharrak eskuratzeak huts egin du.",
    "Fetching note {id} has failed." : "{id} oharrak eskuratzeak huts egin du.",
    "Refreshing note {id} has failed." : "{id} oharra freskatzeak huts egin du.",
    "Renaming note {id} has failed." : "{id} oharra berrizendatzeak huts egin du.",
    "Creating new note has failed." : "Ohar berria sortzeak huts egin du.",
    "Saving note {id} has failed." : "{id} oharra gordetzeak huts egin du.",
    "Updating title for note {id} has failed." : "{id} oharrari izenburua eguneratzeak huts egin du.",
    "Undo delete has failed for note {title}." : "{title} oharra ezabatzea desegiteak huts egin du.",
    "Deleting note {id} has failed." : "{id} oharra ezabatzeak huts egin du.",
    "Toggling favorite for note {id} has failed." : "{id} oharrari gogoko egoera txandakatzeak huts egin du.",
    "Updating the note's category has failed. Is the target directory writable?" : "Oharraren kategoria eguneratzeak huts egin du. Helburuko direktorioan idatzi al daiteke?",
    "Updating the category for note {id} has failed." : "{id} oharraren kategoria eguneratzeak huts egin du.",
    "Development Mode" : "Garapen modua",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Oharrak aplikazioa garapeneko iturburutik instalatu zela dirudi. Horren ordez, instalatu <a href=\"%1$s\">Nextcloud aplikazio biltegi</a> ofizialetik. Oharrak aplikazioa zuk zeuk eraiki nahi baduzu, jarraitu <a href=\"%2$s\">garatzaileentzako jarraibideak</a>."
},
"nplurals=2; plural=(n != 1);");
