OC.L10N.register(
    "notes",
    {
    "Notes" : "Σημειώσεις",
    "Reading notes from filesystem has failed." : "Η ανάγνωση από το αρχείο συστήματος απέτυχε.",
    "Error" : "Σφάλμα",
    "New note" : "Νέα σημείωση",
    "Distraction-free notes and writing" : "Χωρίς περιορισμούς σημειώσεις και γραφή",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Η εφαρμογή \"Σημειώσεις\" είναι μια χωρίς περιττά εφαρμογή διαχείρισης σημειώσεων για το [Nextcloud](https://www.nextcloud.com/). Παρέχει κατηγορίες για καλύτερη οργάνωση και υποστηρίζει μορφοποίηση χρησιμοποιώντας τη σύνταξη [Markdown] (https://en.wikipedia.org/wiki/Markdown). Οι σημειώσεις αποθηκεύονται ως αρχεία στο Nextcloud, ώστε να μπορείτε να τα προβάλετε και να τα επεξεργαστείτε με κάθε λογισμικό Nextcloud. Επιπλέον, ένα ξεχωριστό [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) επιτρέπει την εύκολη ενσωμάτωση σε εφαρμογές τρίτων (προς το παρόν, υπάρχουν εφαρμογές σημειώσεων για το  [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) και [console](https://git.danielmoch.com/nncli/about) που επιτρέπουν εύκολη πρόσβαση στις σημειώσεις σας στο Nextcloud). Άλλα χαρακτηριστικά περιλαμβάνουν την επισήμανση σημειώσεων ως αγαπημένων.",
    "Please see Nextcloud server log for details." : "Για λεπτομέρειες παρακαλούμε δείτε το ιστορικό του διακομιστή Nextcloud.",
    "Deleted {title}" : "Διεγραμμένες {title}",
    "Undo Delete" : "Αναίρεση διαγραφής",
    "Note recovered" : "Η σημείωση ανακτήθηκε",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν σημειώσεις που δεν έχουν αποθηκευτεί. Φεύγοντας από την σελίδα θα διαγραφούν οι αλλαγές!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Διαγράφηκε {number} σημείωση","Διαγράφηκαν {number} σημειώσεις"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Επαναφέρθηκε {number} σημείωση","Επαναφέρθηκαν {number} σημειώσεις"],
    "Notes settings" : "Ρυθμίσεις σημειώσεων",
    "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
    "Root directory" : "Ριζικός κατάλογος",
    "File extension for new notes" : "Πρόσθετο αρχείου για νέες σημειώσεις",
    "Display mode for notes" : "Λειτουργία εμφάνισης για τις σημειώσεις",
    "User defined" : "Ορισμένο από τον χρήστη",
    "Open in edit mode" : "Άνοιγμα για επεξεργασία",
    "Open in preview mode" : "Άνοιγμα για προεπισκόπιση",
    "No notes yet" : "Δεν υπάρχουν ακόμα σημειώσεις",
    "Upload image" : "Μεταφόρτωση εικόνας",
    "Insert image" : "Εισαγωγή εικόνας",
    "Select an image" : "Επιλέξτε μια εικόνα",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Δεν μπορείτε να επιλέξετε εικόνες εκτός του φακέλου των σημειώσεων σας. Ο φάκελος των σημειώσεων σας είναι: {folder}",
    "Wrong image" : "Λάθος εικόνα",
    "The file was not uploaded. Check your server logs." : "Το αρχείο δεν μεταφορτώθηκε. Ελέγξτε τα αρχεία καταγραφής του διακομιστή σας.",
    "All notes" : "Όλες οι σημειώσεις",
    "Categories" : "Κατηγορίες",
    "Loading …" : "Φόρτωση…",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθές",
    "This week" : "Αυτή την εβδομάδα",
    "Last week" : "Προηγούμενη εβδομάδα",
    "This month" : "Αυτό το μήνα",
    "Last month" : "Προηγούμενος μήνας",
    "Rename" : "Μετονομασία",
    "Note's title" : "Τίτλος σημειωματάριου",
    "Delete note" : "Διαγραφή σημείωσης",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα ",
    "Error during preparing note for deletion." : "Σφάλμα κατά την προετοιμασία της σημείωσης για διαγραφή.",
    "The note has been changed in another session. Please choose which version should be saved." : "Η σημείωση έχει τροποποιηθεί σε μια άλλη συνεδρία. Επιλέξτε ποια έκδοση θα αποθηκευτεί.",
    "Use version from server" : "Χρησιμοποιήστε την έκδοση από τον διακομιστή",
    "Use current version" : "Χρησιμοποιήστε την τρέχουσα έκδοση",
    "Empty note" : "Κενή σημείωση",
    "Write …" : "Σύνταξη ...",
    "Details" : "Λεπτομέρειες",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Επεξεργασία",
    "Preview" : "Προεπισκόπηση",
    "Exit full screen" : "Έξοδος πλήρους οθόνης",
    "Full screen" : "Πλήρης οθόνη",
    "Note is read-only. You cannot change it." : "Η σημείωση είναι μόνο για ανάγνωση. Δεν μπορείτε να την αλλάξετε.",
    "Save failed. Click to retry." : "Η αποθήκευση απέτυχε. Κλίκ για προσπάθεια ξανά.",
    "Update conflict. Click for resolving manually." : "Διένεξη κατά την ενημέρωση. Κάντε κλικ για μη αυτόματη επίλυση.",
    "Error from Nextcloud server: {msg}" : "Σφάλμα από τον διακομιστή Nextcloud: {msg}",
    "Category" : "Κατηγορία",
    "Uncategorized" : "Χωρίς κατηγορία",
    "Set category" : "Ορίστε κατηγορία",
    "Click here to save manually" : "Κλίκ εδώ για χειροκίνητη αποθήκευση",
    "Saving failed!" : "Απέτυχε η αποθήκευση!",
    "Last modified: {date}" : "Τελευταία τροποίηση: {date}",
    "Note has unsaved changes" : "Η σημείωση έχει αλλαγές που δεν έχουν αποθηκευτεί",
    "Subcategory" : "Υποκατηγορία",
    "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
    "_%n character_::_%n characters_" : ["%n χαρακτήρας","%n χαρακτήρες"],
    "Write down your thoughts without any distractions." : "Κρατήστε τις σκέψεις σας χωρίς περιορισμούς.",
    "Use Markdown markups to style your text." : "Με χρήση του Markdown για να δώσετε στυλ στο κείμενό σας.",
    "Organize your notes in categories." : "Οργανώστε τις σημειώσεις σας σε κατηγορίες.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Εγκαταστήστε την εφαρμογή στο κινητό σας για πρόσβαση από οπουδήποτε.",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Ξεκινήστε μια σημείωση κάνοντας κλικ στο \"{newnote}\" από το μενού εφαρμογών.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Μπορείτε να δημιουργήσετε υποκατηγορίες χρησιμοποιώντας το \"/\" ως οριοθέτη μεταξύ της κατηγορίας και της υποκατηγορίας, π.χ. \"{Parent}/{sub}\".",
    "Note not found." : "Δεν βρέθηκε η σημείωση.",
    "Note is locked." : "Η σημείωση είναι κλειδωμένη.",
    "Insufficient storage." : "Μη επαρκής αποθηκευτικός χώρος.",
    "See JavaScript console and server log for details." : "Δείτε την κονσόλα JavaScript και το ιστορικό του διακομιστή για λεπτομέρειες.",
    "Updating settings has failed." : "Η ενημέρωση ρυθμίσεων απέτυχε.",
    "Fetching notes for dashboard has failed." : "Η λήψη σημειώσεων για τον πίνακα ελέγχου απέτυχε.",
    "Fetching notes has failed." : "Η λήψη σημειώσεων απέτυχε.",
    "Fetching note {id} has failed." : "Η λήψη της σημείωσης {id} απέτυχε.",
    "Refreshing note {id} has failed." : "Η ανανέωση της σημείωσης {id} απέτυχε.",
    "Renaming note {id} has failed." : "Η μετονομασία της σημείωσης {id} απέτυχε.",
    "Creating new note has failed." : "Η δημιουργία νέας σημείωσης απέτυχε.",
    "Saving note {id} has failed." : "Η αποθήκευση της σημείωσης {id} απέτυχε.",
    "Updating title for note {id} has failed." : "Η ενημέρωση του τίτλου της σημείωσης {id} απέτυχε.",
    "Undo delete has failed for note {title}." : "Η αναίρεση διαγραφής της σημείωσης {title} απέτυχε.",
    "Deleting note {id} has failed." : "Η διαγραφή της σημείωσης {id} απέτυχε.",
    "Toggling favorite for note {id} has failed." : "Η εναλλαγή του αγαπημένου για τη σημείωση {id} απέτυχε.",
    "Updating the note's category has failed. Is the target directory writable?" : "Η ενημέρωση της κατηγορίας σημείωσης απέτυχε. Ο κατάλογος είναι εγγράψιμος;",
    "Updating the category for note {id} has failed." : "Η ενημέρωση της κατηγορίας σημείωσης {id} απέτυχε.",
    "Development Mode" : "Κατάσταση προγραμματισμού",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Φαίνεται ότι η εφαρμογή σημειώσεων εγκαταστάθηκε από μια τρίτη πηγή ανάπτυξης. Παρακαλούμε εγκαταστήστε από την επίσημη <a href=\"%1$s\"> Αγορά Εφαρμογών Nextcloud</a>. Αν επιθυμείτε να αναπτύξετε την εφαρμογή Σημειώσεων, παρακαλούμε ακολουθήστε τις <a href=\"%2$s\">οδηγίες προγραμματιστών</a>."
},
"nplurals=2; plural=(n != 1);");
