OC.L10N.register(
    "notes",
    {
    "Notes" : "Notoj",
    "Error" : "Eraro",
    "New note" : "Nova noto",
    "Distraction-free notes and writing" : "Sendistraj notoj kaj skribado",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Estas nekonservitaj notoj. Foriro el la paĝo perdos ĉiujn ŝanĝojn!",
    "Folder to store your notes" : "Dosiero, en kiu konservi viajn notojn",
    "File extension for new notes" : "Dosiersufikso por novaj notoj",
    "Insert image" : "Enmeti bildon",
    "All notes" : "Ĉiuj notoj",
    "Categories" : "Kategorioj",
    "Loading …" : "Ŝargado...",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "Rename" : "Alinomi",
    "Delete note" : "Forigi noton",
    "Remove from favorites" : "Forigi el pliŝataĵoj",
    "Add to favorites" : "Aldoni al pliŝataĵoj",
    "Use current version" : "Uzi nunan version",
    "Details" : "Detaloj",
    "Edit" : "Modifi",
    "Preview" : "Antaŭvidi",
    "Category" : "Kategorio",
    "Uncategorized" : "Senkategoria",
    "Saving failed!" : "Konservado malsukcesis!",
    "_%n word_::_%n words_" : ["%n vorto","%n vortoj"],
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Updating the note's category has failed. Is the target directory writable?" : "Ĝisdaztigo de la nota kategorio malsukcesis. Ĉu la celdosierujo skribeblas?"
},
"nplurals=2; plural=(n != 1);");
