OC.L10N.register(
    "notes",
    {
    "Notes" : "Бележки",
    "Reading notes from filesystem has failed." : "Четенето на бележки от файлова система е неуспешно.",
    "Error" : "Грешка",
    "New note" : "Нова бележка",
    "Distraction-free notes and writing" : "Бележки и писане без разсейване ",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Приложението Notes е приложение за водене на бележки без разсейване за [Nextcloud] (https://www.nextcloud.com/). То предоставя категории за по-добра организация и поддържа форматиране, използвайки синтаксиса [Markdown] (https://en.wikipedia.org/wiki/Markdown). Бележките се записват като файлове във вашия Nextcloud, така че можете да ги преглеждате и редактирате с всеки клиент на Nextcloud. Освен това, отделен [REST API] (https://github.com/nextcloud/notes/blob/master/docs/api/README.md) позволява лесна интеграция в приложения на трети страни (в момента има приложения за бележки за [Android] (https://github.com/stefan-niedermann/nextcloud-notes), [iOS] (https://github.com/owncloud/notes-iOS-App) и [конзолата] (https: //git.danielmoch.com/nncli/about), които позволяват удобен достъп до вашите бележки на Nextcloud). Допълнителните функции включват маркиране на бележки като любими.",
    "Please see Nextcloud server log for details." : "За подробности вижте дневника на сървъра Nextcloud.",
    "Deleted {title}" : "Изтрито {title}",
    "Undo Delete" : "Отмяна на изтриването",
    "Note recovered" : "Бележката е възстановена",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Има незаписани бележки. Напускайте тази страница, направени промени ще бъдат загубени!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Изтрити {number} бележки","Изтрити  {number} бележки"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Възстановени {number} бележки","Възстановени {number} бележки"],
    "Notes settings" : "Настройки на бележки",
    "Folder to store your notes" : "Папка за съхранение на бележките",
    "Root directory" : "Основна директория",
    "File extension for new notes" : "Разширение за файловете",
    "Display mode for notes" : "Режим на показване на бележки",
    "User defined" : "Дефиниран от потребителя",
    "Open in edit mode" : "Отваряне в режим за редактиране",
    "Open in preview mode" : "Отваряне в режим на визуализация",
    "No notes yet" : "Не са открити бележки",
    "Upload image" : "Качване на изображение",
    "Insert image" : "Вмъкване на изображение",
    "Select an image" : "Избор на изображение",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Не можете да избирате изображения извън вашата папка с бележки. Вашата папка с бележки е: {folder}",
    "Wrong image" : "Грешно изображение",
    "The file was not uploaded. Check your server logs." : "Файлът не беше качен. Проверете регистрите /журнали/ на вашия сървър.",
    "All notes" : "Всички бележки",
    "Categories" : "Категории",
    "Loading …" : "Зарежда …",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "This week" : "Тази седмица",
    "Last week" : "Миналата седмица",
    "This month" : "Този месец",
    "Last month" : "Миналия месец",
    "Rename" : "Преименувай",
    "Note's title" : "Заглавие на бележка",
    "Delete note" : "Изтрий бележката",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "Error during preparing note for deletion." : "Грешка при подготовката на бележка за изтриване.",
    "The note has been changed in another session. Please choose which version should be saved." : "Бележката е променена в друга сесия. Моля, изберете коя версия да бъде запазена.",
    "Use version from server" : "Използване на версия от сървъра",
    "Use current version" : "Използване на текуща версия",
    "Empty note" : "Празна бележка",
    "Write …" : "Писане ...",
    "Details" : "Подробности",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Променяне",
    "Preview" : "Преглед",
    "Exit full screen" : "Изход от цял екран",
    "Full screen" : "Цял екран",
    "Note is read-only. You cannot change it." : "Забележката е само за четене. Не можете да я промените.",
    "Save failed. Click to retry." : "Записването не бе успешно. Щракнете за нов опит.",
    "Update conflict. Click for resolving manually." : "Конфликт с актуализиране. Кликнете, за ръчно разрешаване.",
    "Error from Nextcloud server: {msg}" : "Грешка от Nextcloud сървър: {msg}",
    "Set category" : "Задава категория",
    "Category" : "Категория",
    "Uncategorized" : "Некатегоризирана",
    "Click here to save manually" : "Кликнете тук, за да запишете ръчно",
    "Saving failed!" : "Записването се провали!",
    "Last modified: {date}" : "Последна промяна: {date}",
    "Note has unsaved changes" : "Бележката има незаписани промени.",
    "Subcategory" : "Подкатегория",
    "_%n word_::_%n words_" : ["%n дума","%n думи"],
    "_%n character_::_%n characters_" : ["%n символи","%nсимволи"],
    "Write down your thoughts without any distractions." : "Запишете мислите си без разсейване.",
    "Use Markdown markups to style your text." : "Използване на Markdown маркировки , за да оформите текста си.",
    "Organize your notes in categories." : "Организирайте бележките си в категории.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирайте приложението за мобилния си телефон, за да имате достъп до бележките си отвсякъде.",
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложениер",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Започнете да пишете бележка, като кликнете върху „{newnote}“ в навигацията на приложението.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да създадете подкатегории, като използвате „/“ като разделител между родителска категория и подкатегория, напр. “{parent}/{sub}”.",
    "Note not found." : "Бележката не е открита.",
    "Note is locked." : "Бележката е заключена.",
    "Insufficient storage." : "Недостатъчно място в хранилище.",
    "See JavaScript console and server log for details." : "Вижте конзолата на JavaScript и дневника на сървъра за подробности.",
    "Updating settings has failed." : "Неуспешно актуализиране на настройки",
    "Fetching notes for dashboard has failed." : "Извличането на бележки за таблото за управление не бе успешно.",
    "Fetching notes has failed." : "Извличането на бележки не бе успешно.",
    "Fetching note {id} has failed." : "Извличането на бележка {id} не бе успешно.",
    "Refreshing note {id} has failed." : " Обновяването на бележка {id} не бе успешно.",
    "Renaming note {id} has failed." : " Преименуването на бележка {id} не бе успешно.",
    "Creating new note has failed." : "Създаването на нова бележка {id} не бе успешно.",
    "Saving note {id} has failed." : "Запазването на бележка {id} не бе успешно.",
    "Updating title for note {id} has failed." : "Актуализирането на заглавието на бележка {id} не бе успешно.",
    "Undo delete has failed for note {title}." : "Отмяната на изтриването не бе успешна за бележка {title}.",
    "Deleting note {id} has failed." : "Изтриването на бележка {id} не бе успешно.",
    "Toggling favorite for note {id} has failed." : "Превключването на любими за бележка {id} не бе успешно.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешен опит за промяна на категорията. Може ли да се пише в папката на бележките?",
    "Updating the category for note {id} has failed." : "Актуализирането на категорията за бележка {id} не бе успешно.",
    "Development Mode" : "Режим на разработка",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Изглежда, че приложението за бележки е инсталирано от източник за разработка. Вместо това го инсталирайте от официалния <a href=\"%1$s\"> Nextcloud  App Store</a>. Ако искате сами да създадете приложението Notes, моля, следвайте <a href=\"%2$s\">инструкциите за разработчици</a>."
},
"nplurals=2; plural=(n != 1);");
