OC.L10N.register(
    "notes",
    {
    "Notes" : "Poznámky",
    "Reading notes from filesystem has failed." : "Načítání poznámek ze souborového systému se nezdařilo.",
    "Error" : "Chyba",
    "New note" : "Nová poznámka",
    "Distraction-free notes and writing" : "Pozornost nerozptylující poznámky a zápisky",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikace Poznámky je nerušivý editor pro zapisování poznámek pro [Nextcloud](https://www.nextcloud.com/). Poskytuje kategorie pro lepší uspořádávání a podporuje formátování pomocí [Markdown](https://en.wikipedia.org/wiki/Markdown) syntaxe. Poznámky jsou ukládány jako soubory ve vašem Nextcloud, takže je můžete zobrazovat a upravovat na jakémkoli Nextcloud klientovi. Dále, oddělené [RESTful API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) umožňuje napojení do aplikací třetích stran (v tuto chvíli jsou zde aplikace pro [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) a [konzoli](https://git.danielmoch.com/nncli/about), které umožňují pohodlný přístup k vašim poznámkám na Nextcloud). Mezi další funkce patří označování poznámek jako oblíbené.",
    "Please see Nextcloud server log for details." : "Podrobnosti naleznete v záznamu událostí (log) Nextcloud serveru.",
    "Deleted {title}" : "Smazáno {title}",
    "Undo Delete" : "Vzít zpět vymazání",
    "Note recovered" : "Poznámka obnovena",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Máte neuložené poznámky. Opuštění stránky zahodí všechny změny!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Smazána {number} poznámka","Smazány {number} poznámky","Smazáno {number} poznámek","Smazány {number} poznámky"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Obnovena {number} poznámka","Obnoveny {number} poznámky","Obnoveno {number} poznámek","Obnoveny {number} poznámky"],
    "Notes settings" : "Nastavení pro Poznámky",
    "Folder to store your notes" : "Složka pro ukládání vašich poznámek",
    "Root directory" : "Kořenová složka",
    "File extension for new notes" : "Přípona souboru pro nové poznámky",
    "Display mode for notes" : "Režim zobrazení poznámek",
    "User defined" : "Uživatelsky určené",
    "Open in edit mode" : "Otevřít v režimu úprav",
    "Open in preview mode" : "Otevřít v náhledovém režimu",
    "No notes yet" : "Zatím žádné poznámky",
    "Upload image" : "Nahrát obrázek",
    "Insert image" : "Vložit obrázek",
    "Select an image" : "Vyberte obrázek",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Není možné vybírat obrázky nacházející se mimo vaši složku s poznámkami. Vaše složka s poznámkami je: {folder}",
    "Wrong image" : "Chybný obrázek",
    "The file was not uploaded. Check your server logs." : "Soubor nebyl nahrán. Podívejte se do záznamů událostí na serveru.",
    "All notes" : "Všechny poznámky",
    "Categories" : "Kategorie",
    "Loading …" : "Načítání…",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "This week" : "Tento týden",
    "Last week" : "Minulý týden",
    "This month" : "Tento měsíc",
    "Last month" : "Minulý měsíc",
    "Rename" : "Přejmenovat",
    "Note's title" : "Nadpis poznámky",
    "Delete note" : "Smazat poznámku",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "Error during preparing note for deletion." : "Chyba při přípravě vymazání poznámky.",
    "The note has been changed in another session. Please choose which version should be saved." : "Poznámka byla upravena v jiném sezení. Zvolte, která verze má být uložena.",
    "Use version from server" : "Použít verzi ze serveru",
    "Use current version" : "Použít stávající verzi",
    "Empty note" : "Prázdná poznámka",
    "Write …" : "Zapsat…",
    "Details" : "Podrobnosti",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Upravit",
    "Preview" : "Náhled",
    "Exit full screen" : "Opustit celou obrazovku",
    "Full screen" : "Na celou obrazovku",
    "Note is read-only. You cannot change it." : "Poznámka je pouze pro čtení. Nemůžete ji měnit.",
    "Save failed. Click to retry." : "Uložení se nezdařilo. Klikněte pro opětovný pokus.",
    "Update conflict. Click for resolving manually." : "Konflikt aktualizace. Pokud chcete vyřešit ručně, klikněte sem.",
    "Error from Nextcloud server: {msg}" : "Chyba z Nextcloud serveru: {msg}",
    "Set category" : "Nastavit kategorii",
    "Category" : "Kategorie",
    "Uncategorized" : "Nezařazené",
    "Click here to save manually" : "Kliknutím sem uložíte ručně",
    "Saving failed!" : "Ukládání se nezdařilo!",
    "Last modified: {date}" : "Naposledy změněno: {date}",
    "Note has unsaved changes" : "V poznámce jsou neuložené změny",
    "Subcategory" : "Podkategorie",
    "_%n word_::_%n words_" : ["%n slovo","%n slova","%n slov","%n slova"],
    "_%n character_::_%n characters_" : ["%n znak","%n znaky","%n znaků","%n znaky"],
    "Write down your thoughts without any distractions." : "Zapište si své myšlenky, aniž byste u toho byli rozptylováni.",
    "Use Markdown markups to style your text." : "Pro formátování textu použijte Markdown značky.",
    "Organize your notes in categories." : "Uspořádávejte své poznámky do kategorií.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Abyste ke svým poznámkám měli přístup odkudkoli, nainstalujte si aplikaci do mobilního zařízení.",
    "Android app" : "Aplikace pro Android",
    "iOS app" : "Aplikace pro iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Psaní poznámky zahájíte kliknutím na „{newnote}“ v navigaci aplikace.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Dílčí kategorie je možné vytvářet použitím „/“ (dopředné lomítko) jako oddělovače mezi nadřazenou kategorií a podkategorií, např.: „{nadřazená}/{podkategorie}“.",
    "Note not found." : "Poznámka nenalezena.",
    "Note is locked." : "Poznámka je uzamčena.",
    "Insufficient storage." : "Nedostatečná kapacita úložiště,",
    "See JavaScript console and server log for details." : "Podrobnosti viz konzole JavaScript a záznamy událostí na serveru.",
    "Updating settings has failed." : "Aktualizace nastavení se nezdařila.",
    "Fetching notes for dashboard has failed." : "Načítání poznámek pro nástěnku se nezdařilo.",
    "Fetching notes has failed." : "Načítání poznámek se nezdařilo.",
    "Fetching note {id} has failed." : "Načítání poznámky {id} se nezdařilo.",
    "Refreshing note {id} has failed." : "Znovunačtení poznámky {id} se nezdařilo.",
    "Renaming note {id} has failed." : "Přejmenování poznámky {id} se nezdařilo.",
    "Creating new note has failed." : "Vytváření nové poznámky se nezdařilo.",
    "Saving note {id} has failed." : "Uložení poznámky {id} se nezdařilo.",
    "Updating title for note {id} has failed." : "Aktualizace nadpisu poznámky {id} se nezdařila.",
    "Undo delete has failed for note {title}." : "Vzetí vymazání poznámky {title} zpět se nezdařilo.",
    "Deleting note {id} has failed." : "Mazání poznámky {id} se nezdařilo.",
    "Toggling favorite for note {id} has failed." : "Označení / zrušení označení poznámky {id} jako oblíbené se nezdařilo.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualizace kategorie poznámky se nezdařila. Je cílový adresář přístupný pro zápis?",
    "Updating the category for note {id} has failed." : "Aktualizace kategorie u poznámky {id} se nezdařila.",
    "Development Mode" : "Režim pro vývojáře",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Zdá se, že aplikace Poznámky byla nainstalována ze zdroje pro vývojáře. Nainstalujte ji namísto toho z oficiálního <a href=\"%1$s\">Nextcloud katalogu aplikací</a>. Pokud si chcete sestavit (zkompilovat) aplikaci Poznámky sami, následujte <a href=\"%2$s\">pokyny pro vývojáře</a>."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
