OC.L10N.register(
    "notes",
    {
    "Notes" : "笔记",
    "Reading notes from filesystem has failed." : "从文件系统读取笔记失败。",
    "Error" : "错误",
    "New note" : "新建笔记",
    "Distraction-free notes and writing" : "无干扰的笔记和写作",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "笔记是用于 [Nextcloud](https://www.nextcloud.com/) 的无干扰记录笔记的应用程序。它提供了易于组织的分类，并支持使用 [Markdown](https://en.wikipedia.org/wiki/Markdown) 语法进行格式化。笔记将在您的 Nextcloud 中保存为文件，因此您可以使用每个 Nextcloud 客户端查看和编辑它们。此外，单独的 [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) 允许其轻松集成到第三方应用程序（当前，适用于 [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) 和 [console](https://git.danielmoch.com/nncli/about) 的笔记应用可用于方便地访问您的 Nextcloud 笔记）。其他功能包括将注释标记为收藏。",
    "Please see Nextcloud server log for details." : "有关详情请参阅 Nextcloud 服务器日志。",
    "Deleted {title}" : "已删除 {title}",
    "Undo Delete" : "撤销删除",
    "Note recovered" : "笔记已恢复",
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["已删除 {number} 条笔记"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["已恢复 {number} 条笔记"],
    "Folder to store your notes" : "保存您的笔记的文件夹",
    "File extension for new notes" : "新笔记的文件扩展名",
    "Display mode for notes" : "笔记显示模式",
    "Open in edit mode" : "在编辑模式下打开",
    "Open in preview mode" : "在预览模式下打开",
    "No notes yet" : "还没有便签",
    "Insert image" : "插入图片",
    "All notes" : "所有笔记",
    "Categories" : "分类",
    "Loading …" : "正在加载…",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "This week" : "本周",
    "Last week" : "上周",
    "This month" : "本月",
    "Last month" : "上月",
    "Rename" : "重命名",
    "Note's title" : "笔记标题",
    "Delete note" : "删除笔记",
    "Remove from favorites" : "从收藏夹移除",
    "Add to favorites" : "添加到收藏夹",
    "Error during preparing note for deletion." : "准备删除笔记时出错。",
    "The note has been changed in another session. Please choose which version should be saved." : "笔记已在另一会话中被更改。请选择要保存的版本。",
    "Use version from server" : "使用服务器版本",
    "Use current version" : "使用当前版本",
    "Empty note" : "空笔记",
    "Write …" : "编写 ...",
    "Details" : "详细信息",
    "CTRL + /" : "CTRL + /",
    "Edit" : "编辑",
    "Preview" : "预览",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Note is read-only. You cannot change it." : "笔记为只读状态。你不能更改它。",
    "Save failed. Click to retry." : "保存失败。点击以重试。",
    "Update conflict. Click for resolving manually." : "更新冲突。点击手动解决",
    "Error from Nextcloud server: {msg}" : "来自 Nextcloud 服务器的错误：{msg}",
    "Set category" : "设置分类",
    "Category" : "分类",
    "Uncategorized" : "未分类",
    "Click here to save manually" : "点击这里以手动保存",
    "Saving failed!" : "保存失败！",
    "Last modified: {date}" : "上一次更改：{date}",
    "Note has unsaved changes" : "笔记有未保存的更改",
    "Subcategory" : "子类别",
    "_%n word_::_%n words_" : ["%n 个字"],
    "_%n character_::_%n characters_" : ["%n个字符"],
    "Write down your thoughts without any distractions." : "心无旁骛地写下您的想法。",
    "Use Markdown markups to style your text." : "使用 Markdown 标注来格式化您的文本。",
    "Organize your notes in categories." : "在分类中组织您的笔记。",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "在您的手机中安装此应用以随时随地访问您的笔记。",
    "Android app" : "安卓应用",
    "iOS app" : "iOS 应用",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "在应用导航栏中点击 “{newnote}” 开始做笔记",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "您可以创建子类别，在父类别和子类别之间使用 “/” 作为分隔符，例如 “{parent}/{sub}”。",
    "Note not found." : "未找到笔记",
    "Note is locked." : "笔记已锁定。",
    "Insufficient storage." : "存储空间不足。",
    "See JavaScript console and server log for details." : "有关详情请参见 JavaScript 控制台和服务器日志。",
    "Updating settings has failed." : "更新设置失败。",
    "Fetching notes for dashboard has failed." : "为仪表盘获取笔记失败。",
    "Fetching notes has failed." : "获取笔记失败。",
    "Fetching note {id} has failed." : "获取笔记 {id} 失败。",
    "Refreshing note {id} has failed." : "刷新笔记 {id} 失败。",
    "Renaming note {id} has failed." : "重命名笔记 {id} 失败。",
    "Creating new note has failed." : "创建新笔记失败。",
    "Saving note {id} has failed." : "保存笔记 {id} 失败。",
    "Updating title for note {id} has failed." : "更新笔记 {id} 的标题失败。",
    "Undo delete has failed for note {title}." : "笔记 {title} 的撤消删除失败。",
    "Deleting note {id} has failed." : "删除笔记 {id} 失败。",
    "Toggling favorite for note {id} has failed." : "将笔记 {id} 设为收藏失败。",
    "Updating the note's category has failed. Is the target directory writable?" : "无法更新存储笔记的文件夹。请检查目标文件夹是否可写。",
    "Updating the category for note {id} has failed." : "更新笔记 {id} 的分类失败。",
    "Development Mode" : "开发模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "笔记应用似乎是从一个开发来源安装的。请改从官方<a href=\"%1$s\">Nextcloud 应用商店</a>来安装它。如果您想自己笔记应用，请参考<a href=\"%2$s\">开发者指南</a>。"
},
"nplurals=1; plural=0;");
