OC.L10N.register(
    "notes",
    {
    "Notes" : "ノート",
    "Reading notes from filesystem has failed." : "ファイルシステムからのノートの読み込みに失敗しました。",
    "Error" : "エラー",
    "New note" : "新しいノート",
    "Distraction-free notes and writing" : "集中モードのノートと執筆",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notesアプリは、[Nextcloud](https://www.nextcloud.com/)用の気晴らしに最適なメモアプリです。整理しやすいようにカテゴリを用意しており、[Markdown](https://en.wikipedia.org/wiki/Markdown)の構文を使ったフォーマットをサポートしています。メモはファイルとしてNextcloudに保存されるので、すべてのNextcloudクライアントでメモを表示および編集できます。さらに、別の[REST API](docs/api/README.md)を使用することで、サードパーティ製アプリに簡単に統合することができます(現在、[Android](https://github.com/stefan-niedermann/nextcloud-notes)、[iOS](https://github.com/owncloud/notes-iOS-App)、[コンソール](https://git.danielmoch.com/nncli/about)用のノートアプリがあり、Nextcloudのノートに便利にアクセスすることができます)。さらに、ノートをお気に入りとして登録する機能もあります。",
    "Please see Nextcloud server log for details." : "詳細はNextcloudサーバーログを確認してください。",
    "Deleted {title}" : "{title}を削除しました",
    "Undo Delete" : "削除取り消し",
    "Note recovered" : "ノートが復元されました",
    "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number}つのノートを削除しました"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number}のノートを復元しました"],
    "Folder to store your notes" : "ノートを保存するフォルダー",
    "Root directory" : "ルートディレクトリ",
    "File extension for new notes" : "新しいノートのファイル拡張子",
    "Display mode for notes" : "ノートの表示モード",
    "User defined" : "ユーザー定義",
    "Open in edit mode" : "編集モードで開く",
    "Open in preview mode" : "プレビューモードで開く",
    "No notes yet" : "まだノートはありません",
    "Upload image" : "画像をアップロード",
    "Insert image" : "画像の挿入",
    "Select an image" : "画像を選択",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "ノートのフォルダー外に存在する画像は選択できません。対象ノートのフォルダー: {folder}",
    "Wrong image" : "使用できない画像",
    "The file was not uploaded. Check your server logs." : "ファイルがアップロードされていません。サーバーログをご確認ください。",
    "All notes" : "すべてのノート",
    "Categories" : "カテゴリ",
    "Loading …" : "読み込み中...",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "This week" : "今週",
    "Last week" : "先週",
    "This month" : "今月",
    "Last month" : "先月",
    "Rename" : "名前変更",
    "Note's title" : "ノートタイトル",
    "Delete note" : "ノートを削除",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Error during preparing note for deletion." : "ノートの削除準備中にエラーが発生しました。",
    "The note has been changed in another session. Please choose which version should be saved." : "ノートは他のセッションで変更されました。どのバージョンを保存するか選んでください。",
    "Use version from server" : "サーバーからの版を使用する",
    "Use current version" : "現在の版を使用する",
    "Empty note" : "空白のノート",
    "Write …" : "書き込み …",
    "Details" : "詳細",
    "CTRL + /" : "CTRL + /",
    "Edit" : "編集",
    "Preview" : "プレビュー",
    "Exit full screen" : "全画面を終了",
    "Full screen" : "全画面",
    "Note is read-only. You cannot change it." : "ノートは読み込み専用です。変更はできません。",
    "Save failed. Click to retry." : "保存失敗, クリックで再試行",
    "Update conflict. Click for resolving manually." : "更新が衝突しました。手動で解決するためにクリック。",
    "Error from Nextcloud server: {msg}" : "Nextcloudサーバーエラー: {msg}",
    "Set category" : "カテゴリを設定",
    "Category" : "カテゴリ",
    "Uncategorized" : "未分類",
    "Click here to save manually" : "クリックして手動で保存",
    "Saving failed!" : "保存に失敗しました",
    "Last modified: {date}" : "最終更新: {date}",
    "Note has unsaved changes" : "ノートに変更が保存されていません",
    "Subcategory" : "サブカテゴリ",
    "_%n word_::_%n words_" : ["%n 単語"],
    "_%n character_::_%n characters_" : ["%n文字"],
    "Write down your thoughts without any distractions." : "気を散らすことなくあなたの考えを書き留めてください。",
    "Use Markdown markups to style your text." : "マークダウン・マークアップを使用してテキストを整えます",
    "Organize your notes in categories." : "ノートをカテゴリ別に整理します",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "どこからでもあなたのノートにアクセスするため、あなたの携帯電話にアプリをインストールしてください。",
    "Android app" : "Androidアプリ",
    "iOS app" : "iOSアプリ",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "アプリのナビゲーションで「{newnote}」をクリックしてノートを書き始めます",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "親カテゴリとサブカテゴリの間の区切り文字として「/」を使用して、サブカテゴリを作成できます。 “ {parent} / {sub}”",
    "Note not found." : "ノートが見つかりません。",
    "Note is locked." : "ノートがロックされています。",
    "Insufficient storage." : "容量が不足しています。",
    "See JavaScript console and server log for details." : "詳細については、JavaScriptコンソールとサーバーログを参照してください。",
    "Updating settings has failed." : "設定を更新できませんでした。",
    "Fetching notes for dashboard has failed." : "ダッシュボードでノートを読み込めませんでした。",
    "Fetching notes has failed." : "ノートを取得できませんでした。",
    "Fetching note {id} has failed." : "ノート {id} を取得できませんでした。",
    "Refreshing note {id} has failed." : "ノート {id} を再読み込みできませんでした。",
    "Renaming note {id} has failed." : "ノート {id} をリネームできませんでした。",
    "Creating new note has failed." : "新しいノートを作成できませんでした。",
    "Saving note {id} has failed." : "ノート {id} の保存に失敗しました。",
    "Updating title for note {id} has failed." : "ノート {id} を更新できませんでした。",
    "Undo delete has failed for note {title}." : "ノート {title}の削除取り消しに失敗しました。",
    "Deleting note {id} has failed." : "ノート {id} を削除できませんでした。",
    "Toggling favorite for note {id} has failed." : "お気に入りノート {id} を切り替えできませんでした。",
    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？",
    "Updating the category for note {id} has failed." : "ノート{id}のカテゴリを更新できませんでした。",
    "Development Mode" : "開発モード",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "ノートアプリが開発ソースからインストールされたようです。公式の <a href=\"%1$s\">Nextcloud App Store</a> からインストールしてください。Notesアプリを自分で作成する場合は、 <a href=\"%2$s\">開発者の指示</a>に従ってください。"
},
"nplurals=1; plural=0;");
