OC.L10N.register(
    "notes",
    {
    "Notes" : "Muistiinpanot",
    "Reading notes from filesystem has failed." : "Muistiinpanojen lukeminen tiedostojärjestelmästä epäonnistui.",
    "Error" : "Virhe",
    "New note" : "Uusi muistiinpano",
    "Distraction-free notes and writing" : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
    "Please see Nextcloud server log for details." : "Katso lisätietoja Nextcloud-palvelimen lokista.",
    "Deleted {title}" : "Poistettu {title}",
    "Undo Delete" : "Kumoa poistaminen",
    "Note recovered" : "Muistiinpano palautettu",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Poistettu {number} muistiinpano","Poistettu {number} muistiinpanoa"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Palautettu {number} muistiinpano","Palautettu {number} muistiinpanoa"],
    "Notes settings" : "Muistiinpanojen asetukset",
    "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
    "Root directory" : "Juurihakemisto",
    "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
    "Display mode for notes" : "Muistiinpanojen esitystapa",
    "User defined" : "Käyttäjän määrittelemä",
    "Open in edit mode" : "Avaa muokkaustilassa",
    "Open in preview mode" : "Avaa esikatselutilassa",
    "No notes yet" : "Ei muistiinpanoja",
    "Upload image" : "Lataa kuva",
    "Insert image" : "Lisää kuva",
    "Select an image" : "Valitse kuva",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Et voi valita kuvia muistiinpanohakemiston ulkopuolelta. Muistiinpanojesi hakemisto: {folder}",
    "Wrong image" : "Väärä kuva",
    "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
    "All notes" : "Kaikki muistiinpanot",
    "Categories" : "Luokat",
    "Loading …" : "Ladataan…",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "This week" : "Tällä viikolla",
    "Last week" : "Viime viikolla",
    "This month" : "Tässä kuussa",
    "Last month" : "Viime kuussa",
    "Rename" : "Nimeä uudelleen",
    "Note's title" : "Muistiinpanon otsikko",
    "Delete note" : "Poista muistiinpano",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "Error during preparing note for deletion." : "Virhe valmisteltaessa muistiinpanon poistamista.",
    "The note has been changed in another session. Please choose which version should be saved." : "Muistiinpanoa on muutettu toisessa sessiossa. Valitse, kumpi versio tallennetaan.",
    "Use version from server" : "Käytä versiota palvelimelta",
    "Use current version" : "Käytä nykyistä versiota",
    "Empty note" : "Tyhjä muistiinpano",
    "Write …" : "Kirjoita…",
    "Details" : "Tiedot",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Muokkaa",
    "Preview" : "Esikatselu",
    "Exit full screen" : "Poistu koko näytön tilasta",
    "Full screen" : "Koko näytön tila",
    "Note is read-only. You cannot change it." : "Muistiinpano on kirjoitussuojattu. Et voi tehdä siihen muutoksia.",
    "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
    "Update conflict. Click for resolving manually." : "Konflikti päivityksessä. Klikkaa ratkaistaksesi se manuaalisesti.",
    "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
    "Set category" : "Aseta luokka",
    "Category" : "Luokka",
    "Uncategorized" : "Luokittelematon",
    "Click here to save manually" : "Napsauta tästä tallentaaksesi manuaalisesti",
    "Saving failed!" : "Tallentaminen epäonnistui!",
    "Last modified: {date}" : "Viimeksi muokattu: {date}",
    "Note has unsaved changes" : "Muistiinpanossa ei ole tallentamattomia muutoksia",
    "Subcategory" : "Aliluokka",
    "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
    "_%n character_::_%n characters_" : ["%n merkki","%n merkkiä "],
    "Write down your thoughts without any distractions." : "Kirjaa ajatuksesi ilman häiriötekijöitä.",
    "Use Markdown markups to style your text." : "Käytä Markdown-merkintää tekstille.",
    "Organize your notes in categories." : "Organisoi muistiinpanosi luokkiin.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Asenna sovellus puhelimeesi käyttääksesi muistiinpanoja missä tahansa.",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Aloita muistiinpanon kirjoittaminen napauttamalla \"{newnote}\" navigoinnissa.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Voit luoda alikategorioita käyttämällä /-merkkiä eroittimena yläkategorian ja alikategorian välissä esim: \"{parent}/{sub}\".",
    "Note not found." : "Muistiinpanoa ei löytynyt.",
    "Note is locked." : "Muistiinpano on lukittu.",
    "Insufficient storage." : "Tallennustila ei riitä.",
    "See JavaScript console and server log for details." : "Katso yksityiskohdat JavaScript-konsolista ja palvelimen lokista.",
    "Updating settings has failed." : "Asetusten päivittäminen epäonnistui.",
    "Fetching notes for dashboard has failed." : "Muistiinpanojen noutaminen ohjausnäkymään epäonnistui.",
    "Fetching notes has failed." : "Muistiinpanojen noutaminen epäonnistui.",
    "Fetching note {id} has failed." : "Muistiinpanon {id} noutaminen epäonnistui.",
    "Refreshing note {id} has failed." : "Muistiinpanon {id} uudelleenlataaminen epäonnistui.",
    "Renaming note {id} has failed." : "Muistiinpanon {id} nimeäminen uudelleen epäonnistui.",
    "Creating new note has failed." : "Uuden muistiinpanon luominen epäonnistui.",
    "Saving note {id} has failed." : "Muistiinpanon {id} tallentaminen on epäonnistunut.",
    "Updating title for note {id} has failed." : "Muistiinpanon {id} otsikon vaihtaminen on epäonnistunut.",
    "Undo delete has failed for note {title}." : "Poistamisen kumoaminen epäonnistui muistiinpanolle {title}.",
    "Deleting note {id} has failed." : "Muistiinpanon {id} poistaminen epäonnistui.",
    "Updating the note's category has failed. Is the target directory writable?" : "Muistiinpanon kategorian vaihtaminen epäonnistui. Onko kohdehakemistoon kirjoitusoikeuksia?",
    "Updating the category for note {id} has failed." : "Muistiinpanon {id} kategorian vaihtaminen on epäonnistunut.",
    "Development Mode" : "Kehitystila"
},
"nplurals=2; plural=(n != 1);");
