OC.L10N.register(
    "notes",
    {
    "Notes" : "Märkmed",
    "Error" : "Viga",
    "New note" : "Uus märge",
    "No notes yet" : "Märkmeid veel pole",
    "Categories" : "Kategooriad",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Rename" : "Nimeta ümber",
    "Delete note" : "Kustuta märge",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "Use current version" : "Kasuta praegust versiooni",
    "Details" : "Üksikasjad",
    "Edit" : "Redigeeri",
    "Preview" : "Eelvaade",
    "Category" : "Kategooria",
    "_%n word_::_%n words_" : ["%n sõna","%n sõna"],
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus"
},
"nplurals=2; plural=(n != 1);");
