OC.L10N.register(
    "notes",
    {
    "Notes" : "Minnispunktar",
    "Error" : "Villa",
    "New note" : "Nýr minnispunktur",
    "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
    "Folder to store your notes" : "Mappa til að geyma minnispunktana þína",
    "File extension for new notes" : "Skráarending fyrir nýja minnispunkta",
    "Display mode for notes" : "Birtingarhamur minnispunkta",
    "Open in edit mode" : "Opna í breytingaham",
    "Open in preview mode" : "Opna í forskoðunarham",
    "No notes yet" : "Engir minnispunktar ennþá",
    "Insert image" : "Setja inn mynd",
    "All notes" : "Allir minnispunktar",
    "Categories" : "Flokkar",
    "Loading …" : "Hleð inn …",
    "Today" : "Í dag",
    "Yesterday" : "Yesterday",
    "This week" : "Í þessari viku",
    "This month" : "Í þessum mánuði",
    "Rename" : "Endurnefna",
    "Delete note" : "Eyða minnispunkti",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "Use current version" : "Nota fyrirliggjandi útgáfu",
    "Details" : "Details",
    "Edit" : "Breyta",
    "Preview" : "Forskoðun",
    "Category" : "Flokkur",
    "Uncategorized" : "Óflokkað",
    "Saving failed!" : "Vistun mistókst!",
    "Subcategory" : "Undirflokkur",
    "_%n word_::_%n words_" : ["%n orð","%n orð"],
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppfærsla á flokki minnispunkts mistókst. Er móttökumappan skrifanleg?"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
