OC.L10N.register(
    "notes",
    {
    "Notes" : "Notlar",
    "Reading notes from filesystem has failed." : "Notlar dosya sisteminden okunamadı.",
    "Error" : "Hata",
    "New note" : "Not ekle",
    "Distraction-free notes and writing" : "Dikkatinizi dağıtmadan notlar alabilirsiniz",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Notlar uygulaması [Nextcloud](https://www.nextcloud.com/) için dikkat dağıtmadan not alınabilmesini sağlar. Kategoriler ile daha notları düzenleyebilme ve [Markdown](https://en.wikipedia.org/wiki/Markdown) kod imleri ile biçimlendirme yapılabilmesini sağlar. Notlar Nextcloud alanınıza dosya olarak kaydedilir böylece her Nextcloud istemcisi tarafından görülüp düzenlenebilir. Ayrıca [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) ile üçüncü tarafların uygulamaları ile kolayca bütünleştirilebilir (şu anda  [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) ve [console](https://git.danielmoch.com/nncli/about) için Nextcloud notlarına erişebilen uygulamalar bulunmaktadır). Gelecek sürümlerde notları sık kullanılanlar olarak işaretlemek gibi özellikler sunulacaktır.",
    "Please see Nextcloud server log for details." : "Ayrıntılar için Nextcloud sunucu günlüğüne bakın.",
    "Deleted {title}" : "{title} silindi",
    "Undo Delete" : "Silmeyi geri al",
    "Note recovered" : "Not geri yüklendi",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Kaydedilmemiş notlar var. Sayfadan ayrılırsanız tüm değişiklikler silinecek!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} not silindi","{number} not silindi"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} not geri yüklendi","{number} not geri yüklendi"],
    "Notes settings" : "Notlar ayarları",
    "Folder to store your notes" : "Notlarınızın kaydedileceği klasör",
    "Root directory" : "Kök klasör",
    "File extension for new notes" : "Yeni notlar için dosya uzantısı",
    "Display mode for notes" : "Notların görüntülenme kipi",
    "User defined" : "Kullanıcının belirlediği",
    "Open in edit mode" : "Düzenleme kipinde aç",
    "Open in preview mode" : "Ön izleme kipinde aç",
    "No notes yet" : "Henüz bir not yok",
    "Upload image" : "Görsel yükle",
    "Insert image" : "Görsel ekle",
    "Select an image" : "Bir görsel seçin",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Notlar klasörünüzün dışındaki görselleri seçemezsiniz. Notlar klasörünüz: {folder}",
    "Wrong image" : "Yanlış görsel",
    "The file was not uploaded. Check your server logs." : "Dosya yüklenemedi. Sunucu günlüklerine bakın.",
    "All notes" : "Tüm notlar",
    "Categories" : "Kategoriler",
    "Loading …" : "Yükleniyor …",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "This week" : "Bu hafta",
    "Last week" : "Geçen hafta",
    "This month" : "Bu ay",
    "Last month" : "Geçen ay",
    "Rename" : "Yeniden adlandır",
    "Note's title" : "Not başlığı",
    "Delete note" : "Notu sil",
    "Remove from favorites" : "Sık kullanılanlardan çıkar",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "Error during preparing note for deletion." : "Not silinmeye hazırlanırken sorun çıktı.",
    "The note has been changed in another session. Please choose which version should be saved." : "Bu not başka bir oturumdan değiştirilmiş. Lütfen hangi sürümün kaydedilmesi gerektiğini seçin.",
    "Use version from server" : "Sunucudaki sürüm kullanılsın",
    "Use current version" : "Geçerli sürüm kullanılsın",
    "Empty note" : "Not boş",
    "Write …" : "Yazın …",
    "Details" : "Ayrıntılar",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Düzenle",
    "Preview" : "Ön izleme",
    "Exit full screen" : "Tam ekrandan çık",
    "Full screen" : "Tam ekran",
    "Note is read-only. You cannot change it." : "Not salt okunur olduğundan değiştiremezsiniz.",
    "Save failed. Click to retry." : "Kaydedilemedi. Yeniden denemek için tıklayın.",
    "Update conflict. Click for resolving manually." : "Güncelleme çakışması. El ile çözümlemek için tıklayın.",
    "Error from Nextcloud server: {msg}" : "Nextcloud sunucu hatası: {msg}",
    "Set category" : "Kategoriyi ayarla",
    "Category" : "Kategori",
    "Uncategorized" : "Kategorisiz",
    "Click here to save manually" : "El ile kaydetmek için buraya tıklayın",
    "Saving failed!" : "Kaydedilemedi!",
    "Last modified: {date}" : "Son değişiklik: {date}",
    "Note has unsaved changes" : "Kaydedilmemiş değişiklikler var",
    "Subcategory" : "Alt kategori",
    "_%n word_::_%n words_" : ["%n sözcük","%n sözcük"],
    "_%n character_::_%n characters_" : ["%n karakter","%n karakter"],
    "Write down your thoughts without any distractions." : "Konuyu dağıtmadan düşüncelerinizi yazın.",
    "Use Markdown markups to style your text." : "Metni biçimlendirmek için markdown kod imlerini kullanın.",
    "Organize your notes in categories." : "Kategorileri kullanarak notlarınızı gruplayabilirsiniz.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Notlarınıza her yerden erişebilmek için uygulamayı cep telefonunuza kurun.",
    "Android app" : "Android uygulaması",
    "iOS app" : "iOS uygulaması",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Uygulama menüsünden “{newnote}” üzerine tıklayarak bir not yazmaya başlayın.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Üst kategori ile alt kategori arasında “/” karakterini kullanarak alt kategoriler oluşturabilirsiniz. Örnek “{üst}/{alt}”.",
    "Note not found." : "Not bulunamadı.",
    "Note is locked." : "Not kilitlenmiş.",
    "Insufficient storage." : "Depolama alanı yetersiz.",
    "See JavaScript console and server log for details." : "Ayrıntılı bilgi almak için JavaScript konsoluna ve sunucu günlüğüne bakın.",
    "Updating settings has failed." : "Ayarlar güncellenemedi.",
    "Fetching notes for dashboard has failed." : "Notlar panoya alınamadı.",
    "Fetching notes has failed." : "Notlar alınamadı.",
    "Fetching note {id} has failed." : "Not {id} alınamadı.",
    "Refreshing note {id} has failed." : "Not {id} yenilenemedi.",
    "Renaming note {id} has failed." : "{id} notu yeniden adlandırılamadı.",
    "Creating new note has failed." : "Yeni not eklenemedi.",
    "Saving note {id} has failed." : "{id} notu yeniden kaydedilemedi.",
    "Updating title for note {id} has failed." : "Not {id} başlığı güncellenemedi.",
    "Undo delete has failed for note {title}." : "Silinen {title} notu geri alınamadı.",
    "Deleting note {id} has failed." : "Not {id} silinemedi.",
    "Toggling favorite for note {id} has failed." : "Not {id} sık kullanılanlara eklenemedi/çıkarılamadı.",
    "Updating the note's category has failed. Is the target directory writable?" : "Not kategorisi güncellenemedi. Hedef klasör yazılabilir durumda mı?",
    "Updating the category for note {id} has failed." : "Not {id} kategorisi güncellenemedi.",
    "Development Mode" : "Geliştirme kipi",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Notlar uygulaması bir geliştirme kaynağından kurulmuş gibi görünüyor. Lütfen uygulamayı resmi <a href=\"%1$s\">Nextcloud Uygulama Mağazasından</a> kurun. Notlar uygulamasını kendiniz derlemek istiyorsanız, <a href=\"%2$s\">geliştirici yönergelerine</a> bakabilirsiniz."
},
"nplurals=2; plural=(n > 1);");
