OC.L10N.register(
    "notes",
    {
    "Error" : "ຜິດພາດ",
    "Loading …" : "ກຳລັງໂຫຼດ",
    "Today" : "ມື້ນີ້",
    "Yesterday" : "ມື້ວານນີ້",
    "This week" : "ທິດນີ້",
    "Rename" : "ປ່ຽນຊື່",
    "Remove from favorites" : "ຍ້າຍຈາກລາຍການທີ່ມັກ",
    "Add to favorites" : "ເພີ່ມລາຍການທີ່ມັກ",
    "Details" : "ລາຍລະອຽດ",
    "Edit" : "ແກ້ໄຂ"
},
"nplurals=1; plural=0;");
