OC.L10N.register(
    "notes",
    {
    "Notes" : "Notatki",
    "Reading notes from filesystem has failed." : "Odczytanie notatek z systemu plików nie powiodło się.",
    "Error" : "Błąd",
    "New note" : "Nowa notatka",
    "Distraction-free notes and writing" : "Ogólnodostępne notowanie i pisanie ",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Aplikacja Notatki to bezpłatna aplikacja do robienia notatek dla [Nextcloud](https://www.nextcloud.com/). Zapewnia kategorie dla lepszej organizacji i obsługuje formatowanie przy użyciu składni [Markdown](https://en.wikipedia.org/wiki/Markdown). Notatki są zapisywane jako pliki w Twoim Nextcloud, dzięki czemu możesz je przeglądać i edytować za pomocą każdego klienta Nextcloud. Ponadto osobny [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) pozwala na łatwą integrację z aplikacjami innych firm (obecnie istnieją aplikacje do notatek dla [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) i [konsoli](https://git.danielmoch.com/nncli/about), które umożliwiają wygodny dostęp do notatek Nextcloud). Dodatkowo funkcje obejmują oznaczanie notatek jako ulubionych.",
    "Please see Nextcloud server log for details." : "Szczegółowe informacje można znaleźć w dzienniku serwera Nextcloud.",
    "Deleted {title}" : "Usunięto {title}",
    "Undo Delete" : "Cofnij usunięcie",
    "Note recovered" : "Notatka odzyskana",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Masz niezapisane notatki. Opuszczenie strony spowoduje odrzucenie wszystkich zmian!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Usunięto {number} notatkę","Usunięto {number} notatki","Usunięto {number} notatek","Usunięto {number} notatek"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Odzyskano {number} notatkę","Odzyskano {number} notatki","Odzyskano {number} notatek","Odzyskano {number} notatek"],
    "Notes settings" : "Ustawienia Notatek",
    "Folder to store your notes" : "Katalog do przechowywania notatek",
    "Root directory" : "Katalog główny",
    "File extension for new notes" : "Rozszerzenie pliku dla nowych notatek",
    "Display mode for notes" : "Tryb wyświetlania notatek",
    "User defined" : "Zdefiniowany przez użytkownika",
    "Open in edit mode" : "Otwórz w trybie edycji",
    "Open in preview mode" : "Otwórz w trybie podglądu",
    "No notes yet" : "Brak notatek",
    "Upload image" : "Wyślij obraz",
    "Insert image" : "Wstaw obraz",
    "Select an image" : "Wybierz obraz",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Nie możesz wybrać obrazów poza katalogiem notatek. Twój katalog notatek to: {folder}",
    "Wrong image" : "Nieprawidłowy obraz",
    "The file was not uploaded. Check your server logs." : "Plik nie został wysłany. Sprawdź logi serwera.",
    "All notes" : "Wszystkie notatki",
    "Categories" : "Kategorie",
    "Loading …" : "Wczytywanie…",
    "Today" : "Dzisiaj",
    "Yesterday" : "Wczoraj",
    "This week" : "W tym tygodniu",
    "Last week" : "W zeszłym tygodniu",
    "This month" : "W tym miesiącu",
    "Last month" : "W zeszłym miesiącu",
    "Rename" : "Zmień nazwę",
    "Note's title" : "Tytuł notatki",
    "Delete note" : "Usuń notatkę",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "Error during preparing note for deletion." : "Błąd podczas przygotowywania notatki do usunięcia.",
    "The note has been changed in another session. Please choose which version should be saved." : "Notatka została zmieniona w innej sesji. Proszę wybrać, która wersja ma zostać zapisana.",
    "Use version from server" : "Użyj wersji z serwera",
    "Use current version" : "Użyj bieżącej wersji",
    "Empty note" : "Pusta notatka",
    "Write …" : "Zapisywanie…",
    "Details" : "Szczegóły",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Edycja",
    "Preview" : "Podgląd",
    "Exit full screen" : "Wyłącz tryb pełnoekranowy",
    "Full screen" : "Tryb pełnoekranowy",
    "Note is read-only. You cannot change it." : "Notatka jest tylko do odczytu. Nie możesz jej zmienić.",
    "Save failed. Click to retry." : "Zapisywanie nie powiodło się. Kliknij, aby spróbować ponownie.",
    "Update conflict. Click for resolving manually." : "Zaktualizuj konflikt. Kliknij, aby rozwiązać ręcznie.",
    "Error from Nextcloud server: {msg}" : "Błąd z serwera Nextcloud: {msg}",
    "Set category" : "Ustaw kategorię",
    "Category" : "Kategoria",
    "Uncategorized" : "Bez kategorii",
    "Click here to save manually" : "Kliknij tutaj, aby zapisać ręcznie",
    "Saving failed!" : "Błąd zapisu!",
    "Last modified: {date}" : "Ostatnia modyfikacja: {date}",
    "Note has unsaved changes" : "Notatka ma niezapisane zmiany",
    "Subcategory" : "Podkategoria",
    "_%n word_::_%n words_" : ["%n słowo","%n słowa","%n słów","%n słów"],
    "_%n character_::_%n characters_" : ["%n znak","%n znaki","%n znaków","%n znaków"],
    "Write down your thoughts without any distractions." : "Zapisz swoje myśli, aby nie zapomnieć.",
    "Use Markdown markups to style your text." : "Użyj znaczników Markdown, aby nadać styl tekstowi.",
    "Organize your notes in categories." : "Uporządkuj swoje notatki w kategoriach.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Zainstaluj aplikację na swój telefon komórkowy, aby uzyskać dostęp do notatek z dowolnego miejsca.",
    "Android app" : "Aplikacja Android",
    "iOS app" : "Aplikacja iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Zacznij pisać notatkę, klikając “{newnote}” w nawigacji aplikacji.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Możesz tworzyć podkategorie, używając \"/\" jako separatora między kategorią nadrzędną a podkategorią, np. \"{parent}/{sub}\".",
    "Note not found." : "Nie znaleziono notatki.",
    "Note is locked." : "Notatka jest zablokowana.",
    "Insufficient storage." : "Niewystarczająca ilość miejsca.",
    "See JavaScript console and server log for details." : "Szczegółowe informacje można znaleźć w konsoli JavaScript i w dzienniku serwera.",
    "Updating settings has failed." : "Aktualizacja ustawień nie powiodła się.",
    "Fetching notes for dashboard has failed." : "Pobieranie notatek na pulpit nie powiodło się.",
    "Fetching notes has failed." : "Pobranie notatek nie powiodło się.",
    "Fetching note {id} has failed." : "Pobranie notatki {id} nie powiodło się.",
    "Refreshing note {id} has failed." : "Odświeżenie notatki {id} nie powiodło się.",
    "Renaming note {id} has failed." : "Zmiana nazwy notatki {id} nie powiodła się.",
    "Creating new note has failed." : "Utworzenie nowej notatki nie powiodło się.",
    "Saving note {id} has failed." : "Zapisanie notatki {id} nie powiodło się.",
    "Updating title for note {id} has failed." : "Aktualizacja tytułu notatki {id} nie powiodła się.",
    "Undo delete has failed for note {title}." : "Cofnięcie usunięcia notatki {title} nie powiodło się.",
    "Deleting note {id} has failed." : "Usunięcie notatki {id} nie powiodło się.",
    "Toggling favorite for note {id} has failed." : "Przełączenie ulubionej notatki {id} nie powiodło się.",
    "Updating the note's category has failed. Is the target directory writable?" : "Aktualizacja kategorii notatki nie powiodła się. Czy katalog docelowy jest zapisywalny?",
    "Updating the category for note {id} has failed." : "Aktualizacja kategorii dla notatki {id} nie powiodła się.",
    "Development Mode" : "Tryb deweloperski",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Wygląda na to, że aplikacja Notes została zainstalowana ze źródła deweloperskiego. Zainstaluj ją z oficjalnego sklepu <a href=\"%1$s\">Nextcloud App Store</a>. Jeśli chcesz samodzielnie zbudować aplikację Notes, postępuj zgodnie z <a href=\"%2$s\">instrukcjami dla programistów</a>."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
